@@ -57,7 +57,7 @@
 #include "crc32.h"
 #include "tcplay.h"
 #include "humanize.h"
-
+#include "tcplay_api.h"
 
 /* XXX TODO:
  *  - LRW-benbi support? needs further work in dm-crypt and even opencrypto
@@ -105,12 +105,26 @@ struct pbkdf_prf_algo pbkdf_prf_algos_standard_tc[] = {
 };
 
 struct pbkdf_prf_algo pbkdf_prf_algos_boot_vc[] = {
+	{ "RIPEMD160",	0 },
+	{ "SHA256",	0 },
+	{ NULL,		0 }
+};
+
+static const struct pbkdf_prf_algo _original_pbkdf_prf_algos_boot_vc[] = {
 	{ "RIPEMD160",	327661 },
 	{ "SHA256",	200000 },
 	{ NULL,		0    }
 };
 
 struct pbkdf_prf_algo pbkdf_prf_algos_standard_vc[] = {
+	{ "SHA512",	0 },
+	{ "whirlpool",	0 },
+	{ "SHA256",	0 },
+	{ "RIPEMD160",	0 },
+	{ NULL,		0 }
+};
+
+static const struct pbkdf_prf_algo _original_pbkdf_prf_algos_standard_vc[] = {
 	{ "SHA512",	500000 },
 	{ "whirlpool",	500000 },
 	{ "SHA256",	500000 },
@@ -150,6 +164,33 @@ const char *valid_cipher_chains[][MAX_CIPHER_CHAINS] = {
 	{ NULL }
 };
 
+static void _tc_set_iteration_count(struct pbkdf_prf_algo *s,int iteration_count)
+{
+	int i;
+	for( i = 0 ; ; i++ ){
+		s += i;
+		if(s->name == NULL){
+			break;
+		}else{
+			s->iteration_count = iteration_count;
+		}
+	}
+}
+
+void tc_set_iteration_count(int iteration_count)
+{
+	if (iteration_count > 0){
+		_tc_set_iteration_count(pbkdf_prf_algos_boot_vc,iteration_count);
+		_tc_set_iteration_count(pbkdf_prf_algos_standard_vc,iteration_count);
+	}else{
+		memcpy(pbkdf_prf_algos_boot_vc ,_original_pbkdf_prf_algos_boot_vc,
+		       sizeof(_original_pbkdf_prf_algos_boot_vc));
+
+		memcpy(pbkdf_prf_algos_standard_vc ,_original_pbkdf_prf_algos_standard_vc,
+		       sizeof(_original_pbkdf_prf_algos_standard_vc));
+	}
+}
+
 struct tc_cipher_chain *tc_cipher_chains[MAX_CIPHER_CHAINS];
 
 static
@@ -365,6 +406,15 @@ print_info(struct tcplay_info *info)
 	    (uint64_t)info->offset);
 }
 
+static
+int
+_not_a_device_with_partitions(const char *dev)
+{
+	if (strncmp(dev, "/dev/sd",7) == 0 || strncmp(dev, "/dev/hd",7) == 0)
+		return 0 ;
+	return 1 ;
+}
+
 static
 struct tcplay_info *
 new_info(const char *dev, int flags, struct tc_cipher_chain *cipher_chain,
@@ -383,6 +433,7 @@ new_info(const char *dev, int flags, struct tc_cipher_chain *cipher_chain,
 	}
 
 	strncpy(info->dev, dev, sizeof(info->dev));
+	info->dev[sizeof(info->dev)-1] = '\0';
 	info->cipher_chain = cipher_chain;
 	info->pbkdf_prf = prf;
 	info->start = start;
@@ -391,18 +442,62 @@ new_info(const char *dev, int flags, struct tc_cipher_chain *cipher_chain,
 	info->size = hdr->sz_mk_scope / hdr->sec_sz;	/* volume size */
 	info->skip = hdr->off_mk_scope / hdr->sec_sz;	/* iv skip */
 
+	if (TC_FLAG_SET(flags, SYS)){
+
+		if (_not_a_device_with_partitions(info->dev)){
+
+			/*
+			 * This device could be loop device or an lvm volume or a raid device or
+			 * any other device that does not spell out partition information.
+			 */
+
+			/*
+			 * this is a tricky device since it has no visible partitions and we
+			 * handle it by simply mapping starting at the beginning of the first partition.
+			 */
+			info->offset = 63;
+
+			/*
+			 * here,we are supposed to set the size of the first partition but we dont have it
+			 * so we set wrong info by setting the size of the disk as it was read from the header.
+			 * Net result is that the created mapper will be of size larger than what it was supposed to be.
+			 */
+			info->size = hdr->sz_mk_scope / hdr->sec_sz;
+		} else {
+
+			/*
+			 * We have a device that has old fashioned partitions
+			 */
+
+			info->offset = 0; /* offset is 0 for system volumes */
+
+			/*
+			 * probe the partition itself to get its size.
+			 */
+			if (get_disk_info(dev, &info->size, NULL) != 0) {
+				tc_log(1, "could not get disk information\n");
+				free_safe_mem(info);
+				return NULL;
+			}
+		}
+	} else {
+		info->offset = hdr->off_mk_scope / hdr->sec_sz;	/* block offset */
+
+		/*
+		 * use volume size as reported by the header since the entire device
+		 * is going to be mapped.
+		 */
+		info->size = hdr->sz_mk_scope / hdr->sec_sz;
+	}
+
 	info->volflags = hdr->flags;
 	info->flags = flags;
 
-	if (TC_FLAG_SET(flags, SYS))
-		info->offset = 0; /* offset is 0 for system volumes */
-	else
-		info->offset = hdr->off_mk_scope / hdr->sec_sz;	/* block offset */
-
 	/* Associate a key out of the key pool with each cipher in the chain */
 	error = tc_cipher_chain_populate_keys(cipher_chain, hdr->keys);
 	if (error) {
 		tc_log(1, "could not populate keys in cipher chain\n");
+		free_safe_mem(info);
 		return NULL;
 	}
 
@@ -441,7 +536,7 @@ adjust_info(struct tcplay_info *info, struct tcplay_info *hinfo)
 }
 
 int
-process_hdr(const char *dev, int flags, unsigned char *pass, int passlen,
+process_hdr(const char *dev, struct tcplay_opts *opts, unsigned char *pass, int passlen,
     struct tchdr_enc *ehdr, int hidden_header, struct tcplay_info **pinfo)
 {
 	struct tchdr_dec *dhdr;
@@ -451,6 +546,8 @@ process_hdr(const char *dev, int flags, unsigned char *pass, int passlen,
 	unsigned char *key;
 	int i, j, found, error, veracrypt_mode;
 
+	int flags = opts->flags ;
+
 	*pinfo = NULL;
 
 	if ((key = alloc_safe_mem(MAX_KEYSZ)) == NULL) {
@@ -797,6 +894,12 @@ create_volume(struct tcplay_opts *opts)
 	if (opts->state_change_fn)
 		opts->state_change_fn(opts->api_ctx, "create_header", 1);
 
+	if (opts->iteration_count > 0){
+		opts->prf_algo->iteration_count = opts->iteration_count;
+		if (opts->h_prf_algo)
+			opts->h_prf_algo->iteration_count = opts->iteration_count;
+	}
+
 	/* create encrypted headers */
 	ehdr = create_hdr((unsigned char *)pass,
 	    (opts->nkeyfiles > 0)?MAX_PASSSZ:strlen(pass),
@@ -1039,7 +1142,7 @@ info_map_common(struct tcplay_opts *opts, char *passphrase_out)
 			hehdr = NULL;
 		}
 
-		error = process_hdr(opts->dev, opts->flags, (unsigned char *)pass,
+		error = process_hdr(opts->dev, opts, (unsigned char *)pass,
 		    (opts->nkeyfiles > 0)?MAX_PASSSZ:strlen(pass),
 		    ehdr, 0, &info);
 
@@ -1050,12 +1153,12 @@ info_map_common(struct tcplay_opts *opts, char *passphrase_out)
 		 */
 		if (hehdr && (error || opts->protect_hidden)) {
 			if (error) {
-				error2 = process_hdr(opts->dev, opts->flags, (unsigned char *)pass,
+				error2 = process_hdr(opts->dev, opts, (unsigned char *)pass,
 				    (opts->nkeyfiles > 0)?MAX_PASSSZ:strlen(pass), hehdr, 1,
 				    &info);
 				is_hidden = !error2;
 			} else if (opts->protect_hidden) {
-				error2 = process_hdr(opts->dev, opts->flags, (unsigned char *)h_pass,
+				error2 = process_hdr(opts->dev, opts, (unsigned char *)h_pass,
 				    (opts->n_hkeyfiles > 0)?MAX_PASSSZ:strlen(h_pass), hehdr, 1,
 				    &hinfo);
 			}
@@ -1190,16 +1293,6 @@ map_volume(struct tcplay_opts *opts)
 	if (info == NULL)
 		return -1;
 
-	info->off_set = 0;
-
-	if (opts->dev && opts->sys_dev){
-		if (strcmp(opts->dev, opts->sys_dev) == 0 ){
-			info->off_set = 63;
-		}
-	}
-
-	info->read_only = opts->read_only;
-
 	if ((error = dm_setup(opts->map_name, info)) != 0) {
 		tc_log(1, "Could not set up mapping %s\n", opts->map_name);
 		free_info(info);
@@ -1582,6 +1675,49 @@ error:
 	return NULL;
 }
 
+static int _string_ends_with(const char *e, size_t ee, const char *s, size_t ss)
+{
+	if (ee >= ss)
+		return memcmp(e + ee - ss, s, ss) == 0;
+	else
+		return 0;
+}
+
+static int _string_starts_and_ends_with(const char *a, const char *b, const char *c)
+{
+	if (strncmp(a, b, strlen(b)) == 0)
+		return _string_ends_with( a, strlen(a), c,strlen(c));
+	else
+		return 0;
+}
+
+static int _string_starts_with(const char *a, const char *b)
+{
+	return strncmp( a, b, strlen(b)) == 0;
+}
+
+void tc_api_get_volume_type(char *buffer, size_t size, const char *map_name)
+{
+	DIR *dir = opendir("/dev/disk/by-id/");
+	struct dirent *e;
+
+	snprintf(buffer, size, "Nil");
+
+	if (dir != NULL){
+		while ((e = readdir(dir)) != NULL){
+			if (_string_starts_and_ends_with(e->d_name, "dm-uuid-CRYPT-", map_name)){
+				if (_string_starts_with(e->d_name, "dm-uuid-CRYPT-TCRYPT")){
+					snprintf(buffer, size, "TCRYPT");
+				}else if (_string_starts_with(e->d_name, "dm-uuid-CRYPT-VCRYPT")){
+					snprintf(buffer, size, "VCRYPT");
+				}
+				break;
+			}
+		}
+		closedir(dir);
+	}
+}
+
 struct tcplay_info *
 dm_info_map(const char *map_name)
 {
@@ -1594,6 +1730,8 @@ dm_info_map(const char *map_name)
 	char ciphers[512];
 	int i, outermost = -1;
 
+	struct dm_info *info_dm;
+
 	memset(dm_table, 0, sizeof(dm_table));
 
 	if ((info = (struct tcplay_info *)alloc_safe_mem(sizeof(*info))) == NULL) {
@@ -1651,6 +1789,7 @@ dm_info_map(const char *map_name)
 
 	/* Copy over the name */
 	strncpy(info->dev, dm_table[outermost]->device, sizeof(info->dev));
+	info->dev[sizeof(info->dev)-1] = '\0';
 
 	/* Other fields */
 	info->hdr = NULL;
@@ -1661,6 +1800,21 @@ dm_info_map(const char *map_name)
 	info->offset = dm_table[outermost]->offset;
 	info->blk_sz = 512;
 
+	info_dm = &dmi[outermost];
+
+	info->read_only = info_dm->read_only;
+
+	if (info_dm->inactive_table)
+		strcpy(info->status, "inactive");
+	else if (info_dm->open_count > 0)
+		strcpy(info->status, "active and is in use");
+	else if (info_dm->open_count == 0)
+		strcpy(info->status, "active");
+	else
+		strcpy(info->status, "invalid");
+
+	tc_api_get_volume_type((char*)&info->type, sizeof(info->type), map_name);
+
 	return info;
 
 error:
@@ -1743,6 +1897,7 @@ dm_setup(const char *mapname, struct tcplay_info *info)
 	}
 
 	strcpy(dev, info->dev);
+
 	/*
 	 * Device Mapper blocks are always 512-byte blocks, so convert
 	 * from the "native" block size to the dm block size here.
@@ -1840,7 +1995,7 @@ dm_setup(const char *mapname, struct tcplay_info *info)
 
 		free(uu);
 
-		if (info->read_only)
+		if (TC_FLAG_SET(info->flags, READ_ONLY_MODE))
 			dm_task_set_ro(dmt);
 
 		if (TC_FLAG_SET(info->flags, FDE)) {
@@ -1865,9 +2020,6 @@ dm_setup(const char *mapname, struct tcplay_info *info)
 			start = INFO_TO_DM_BLOCKS(info, offset);
 		}
 
-		if (info->off_set)
-			offset = info->off_set;
-
 		/* aes-cbc-essiv:sha256 7997f8af... 0 /dev/ad0s0a 8 <opts> */
 		/*			   iv off---^  block off--^ <opts> */
 		snprintf(params, 512, "%s %s %"PRIu64 " %s %"PRIu64 " %s",
@@ -1975,6 +2127,11 @@ dm_teardown(const char *mapname, const char *device __unused)
 	return 0;
 }
 
+int tc_api_close_mapper(const char *mapname)
+{
+	return dm_teardown(mapname, NULL);
+}
+
 struct tc_crypto_algo *
 check_cipher(const char *cipher, int quiet)
 {
