@@ -168,6 +168,8 @@ tc_api_task_init(const char *op)
 		goto out;
 	}
 
+	tc_set_iteration_count(0);
+
 	fail = 0;
 
 out:
@@ -432,7 +434,15 @@ tc_api_task_set(tc_api_task task, const char *key, ...)
 		vp = va_arg(ap, void *);
 		opts->api_ctx = vp;
 	} else if (_match(key, "read_only")) {
-		opts->read_only = 1;
+		i = va_arg(ap, int);
+		if (i)
+			opts->flags |= TC_FLAG_READ_ONLY_MODE;
+		else
+			opts->flags &= ~TC_FLAG_READ_ONLY_MODE;
+	} else if (_match(key, "iteration_count")) {
+		if (TC_FLAG_SET(opts->flags, VERACRYPT_MODE)){
+			tc_set_iteration_count(va_arg(ap, int));
+		}
 	} else {
 		r = TC_ERR_UNIMPL;
 	}
@@ -805,7 +815,21 @@ tc_api_task_info_get(tc_api_task task, const char *key, ...)
 			*i64p = (int64_t)info->offset * (int64_t)info->hdr->sec_sz;
 		else
 			*i64p = (int64_t)info->offset * (int64_t)info->blk_sz;
-	} else {
+	} else if (_match(key, "type")) {
+		s = va_arg(ap, char *);
+		strncpy(s, info->type, sz);
+	} else if (_match(key, "status")) {
+		s = va_arg(ap, char *);
+		strncpy(s, info->status, sz);
+	} else if (_match(key, "mode")) {
+		if (sz != sizeof(int)) {
+			errno = EFAULT;
+			r = TC_ERR;
+			goto out;
+		}
+		ip = va_arg(ap, int *);
+		*ip = info->read_only;
+	}else {
 		r = TC_ERR_UNIMPL;
 	}
 
