@@ -171,154 +171,154 @@ only root user or members of group zulucrypt-write can do that</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/mainwindow.ui" line="123"/>
+        <location filename="../../zuluMount-gui/mainwindow.ui" line="118"/>
         <source>&amp;Mount File</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/mainwindow.ui" line="168"/>
+        <location filename="../../zuluMount-gui/mainwindow.ui" line="138"/>
+        <source>&amp;Menu</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../zuluMount-gui/mainwindow.ui" line="111"/>
         <source>Mount Encf&amp;s</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/mainwindow.ui" line="142"/>
+        <location filename="../../zuluMount-gui/mainwindow.ui" line="131"/>
         <source>&amp;Refresh</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/mainwindow.ui" line="155"/>
-        <source>&amp;Close</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../zuluMount-gui/mainwindow.cpp" line="131"/>
+        <location filename="../../zuluMount-gui/mainwindow.cpp" line="129"/>
         <source>Automount Volumes</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/mainwindow.cpp" line="141"/>
+        <location filename="../../zuluMount-gui/mainwindow.cpp" line="139"/>
         <source>Auto Open Mount Point</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/mainwindow.cpp" line="147"/>
-        <source>Show The Interface</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../zuluMount-gui/mainwindow.cpp" line="153"/>
+        <location filename="../../zuluMount-gui/mainwindow.cpp" line="145"/>
         <source>Unmount All</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/mainwindow.cpp" line="158"/>
+        <location filename="../../zuluMount-gui/mainwindow.cpp" line="150"/>
         <source>Favorites</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/mainwindow.cpp" line="162"/>
+        <location filename="../../zuluMount-gui/mainwindow.cpp" line="154"/>
         <source>Hide Volume From View</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/mainwindow.cpp" line="166"/>
+        <location filename="../../zuluMount-gui/mainwindow.cpp" line="158"/>
         <source>Unhide Volume From View</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/mainwindow.cpp" line="171"/>
+        <location filename="../../zuluMount-gui/mainwindow.cpp" line="163"/>
+        <source>Check For Update</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../zuluMount-gui/mainwindow.cpp" line="168"/>
         <source>About</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/mainwindow.cpp" line="175"/>
+        <location filename="../../zuluMount-gui/mainwindow.cpp" line="172"/>
         <source>Quit</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/mainwindow.cpp" line="229"/>
-        <location filename="../../zuluMount-gui/mainwindow.cpp" line="248"/>
-        <location filename="../../zuluMount-gui/mainwindow.cpp" line="288"/>
+        <location filename="../../zuluMount-gui/mainwindow.cpp" line="240"/>
+        <location filename="../../zuluMount-gui/mainwindow.cpp" line="259"/>
+        <location filename="../../zuluMount-gui/mainwindow.cpp" line="299"/>
         <source>List Is Empty</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/mainwindow.cpp" line="447"/>
-        <location filename="../../zuluMount-gui/mainwindow.cpp" line="454"/>
-        <location filename="../../zuluMount-gui/mainwindow.cpp" line="461"/>
+        <location filename="../../zuluMount-gui/mainwindow.cpp" line="463"/>
+        <location filename="../../zuluMount-gui/mainwindow.cpp" line="470"/>
+        <location filename="../../zuluMount-gui/mainwindow.cpp" line="477"/>
         <source>LABEL=&quot;%1&quot;</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/mainwindow.cpp" line="463"/>
+        <location filename="../../zuluMount-gui/mainwindow.cpp" line="479"/>
         <source>LABEL=&quot;%1&quot;
 %2</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/mainwindow.cpp" line="532"/>
+        <location filename="../../zuluMount-gui/mainwindow.cpp" line="544"/>
         <source>Mount</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/mainwindow.cpp" line="539"/>
+        <location filename="../../zuluMount-gui/mainwindow.cpp" line="551"/>
         <source>Unmount</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/mainwindow.cpp" line="547"/>
-        <location filename="../../zuluMount-gui/mainwindow.cpp" line="570"/>
-        <location filename="../../zuluMount-gui/mainwindow.cpp" line="575"/>
-        <location filename="../../zuluMount-gui/mainwindow.cpp" line="578"/>
+        <location filename="../../zuluMount-gui/mainwindow.cpp" line="559"/>
+        <location filename="../../zuluMount-gui/mainwindow.cpp" line="582"/>
+        <location filename="../../zuluMount-gui/mainwindow.cpp" line="587"/>
+        <location filename="../../zuluMount-gui/mainwindow.cpp" line="590"/>
         <source>Properties</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/mainwindow.cpp" line="555"/>
-        <location filename="../../zuluMount-gui/mainwindow.cpp" line="572"/>
+        <location filename="../../zuluMount-gui/mainwindow.cpp" line="567"/>
+        <location filename="../../zuluMount-gui/mainwindow.cpp" line="584"/>
         <source>Open Folder</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/mainwindow.cpp" line="558"/>
+        <location filename="../../zuluMount-gui/mainwindow.cpp" line="570"/>
         <source>Open Private Folder</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/mainwindow.cpp" line="560"/>
-        <location filename="../../zuluMount-gui/mainwindow.cpp" line="582"/>
+        <location filename="../../zuluMount-gui/mainwindow.cpp" line="572"/>
+        <location filename="../../zuluMount-gui/mainwindow.cpp" line="594"/>
         <source>Open Shared Folder</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/mainwindow.cpp" line="589"/>
+        <location filename="../../zuluMount-gui/mainwindow.cpp" line="601"/>
         <source>Close Menu</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/mainwindow.cpp" line="638"/>
+        <location filename="../../zuluMount-gui/mainwindow.cpp" line="650"/>
         <source>Could not open mount point because &quot;%1&quot; tool does not appear to be working correctly</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/mainwindow.cpp" line="640"/>
+        <location filename="../../zuluMount-gui/mainwindow.cpp" line="652"/>
         <source>Warning</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/mainwindow.cpp" line="666"/>
-        <location filename="../../zuluMount-gui/mainwindow.cpp" line="673"/>
+        <location filename="../../zuluMount-gui/mainwindow.cpp" line="678"/>
+        <location filename="../../zuluMount-gui/mainwindow.cpp" line="685"/>
         <source>Could not get volume properties.
 volume is not open or was opened by a different user</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/mainwindow.cpp" line="670"/>
+        <location filename="../../zuluMount-gui/mainwindow.cpp" line="682"/>
         <source>Volume Properties</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/mainwindow.cpp" line="802"/>
+        <location filename="../../zuluMount-gui/mainwindow.cpp" line="811"/>
         <source>Permission to access the volume was denied
 or
 the volume is not supported
@@ -326,12 +326,12 @@ the volume is not supported
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/mainwindow.cpp" line="832"/>
+        <location filename="../../zuluMount-gui/mainwindow.cpp" line="837"/>
         <source>Select An Image File To Mount</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/mainwindow.cpp" line="846"/>
+        <location filename="../../zuluMount-gui/mainwindow.cpp" line="851"/>
         <source>Select An Encfs Volume Directory</source>
         <translation type="unfinished"></translation>
     </message>
@@ -341,17 +341,17 @@ the volume is not supported
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/mainwindow.cpp" line="1047"/>
+        <location filename="../../zuluMount-gui/mainwindow.cpp" line="1045"/>
         <source>Reading partition properties took longer than expected and operation was terminated,click refresh to try again</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/mainwindow.cpp" line="665"/>
-        <location filename="../../zuluMount-gui/mainwindow.cpp" line="672"/>
-        <location filename="../../zuluMount-gui/mainwindow.cpp" line="801"/>
+        <location filename="../../zuluMount-gui/mainwindow.cpp" line="677"/>
+        <location filename="../../zuluMount-gui/mainwindow.cpp" line="684"/>
+        <location filename="../../zuluMount-gui/mainwindow.cpp" line="810"/>
         <location filename="../../zuluMount-gui/mainwindow.cpp" line="952"/>
         <location filename="../../zuluMount-gui/mainwindow.cpp" line="961"/>
-        <location filename="../../zuluMount-gui/mainwindow.cpp" line="1046"/>
+        <location filename="../../zuluMount-gui/mainwindow.cpp" line="1044"/>
         <source>ERROR</source>
         <translation type="unfinished"></translation>
     </message>
@@ -359,7 +359,7 @@ the volume is not supported
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../../zuluCrypt-gui/utility.cpp" line="132"/>
+        <location filename="../../zuluCrypt-gui/utility.cpp" line="140"/>
         <source>
 options:
 	-d   path to where a volume to be auto unlocked/mounted is located
@@ -369,17 +369,55 @@ options:
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../zuluCrypt-gui/utility.cpp" line="958"/>
+        <location filename="../../zuluCrypt-gui/utility.cpp" line="1049"/>
         <source>about zuluCrypt</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../zuluCrypt-gui/utility.cpp" line="511"/>
+        <location filename="../../zuluCrypt-gui/utility.cpp" line="600"/>
         <source>if the option is checked,a primary private mount point will be created in &quot;/run/media/private/$USER/&quot;
 and a secondary publicly accessible &quot;mirror&quot; mount point will be created in &quot;/run/media/public/&quot;</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>VeraCryptPIMDialog</name>
+    <message>
+        <location filename="../../zuluMount-gui/veracryptpimdialog.ui" line="14"/>
+        <source>VeraCrypt PIM value</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../zuluMount-gui/veracryptpimdialog.ui" line="26"/>
+        <source>&amp;Set</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../zuluMount-gui/veracryptpimdialog.ui" line="39"/>
+        <source>&amp;Cancel</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../zuluMount-gui/veracryptpimdialog.ui" line="52"/>
+        <source>TextLabel</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../zuluMount-gui/veracryptpimdialog.cpp" line="40"/>
+        <source>Set VeraCrypt dynamic mode magic number below.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../zuluMount-gui/veracryptpimdialog.cpp" line="89"/>
+        <source>ERROR</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../zuluMount-gui/veracryptpimdialog.cpp" line="89"/>
+        <source>Failed to convert the value to digits only </source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>deviceOffset</name>
     <message>
@@ -431,8 +469,8 @@ or in terabytes if the entry ends with &quot;t&quot;</source>
     </message>
     <message>
         <location filename="../../zuluMount-gui/keydialog.ui" line="58"/>
-        <location filename="../../zuluMount-gui/keydialog.cpp" line="128"/>
-        <location filename="../../zuluMount-gui/keydialog.cpp" line="633"/>
+        <location filename="../../zuluMount-gui/keydialog.cpp" line="130"/>
+        <location filename="../../zuluMount-gui/keydialog.cpp" line="663"/>
         <source>Key</source>
         <translation type="unfinished"></translation>
     </message>
@@ -457,137 +495,139 @@ or in terabytes if the entry ends with &quot;t&quot;</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/keydialog.cpp" line="376"/>
-        <location filename="../../zuluMount-gui/keydialog.cpp" line="407"/>
-        <location filename="../../zuluMount-gui/keydialog.cpp" line="449"/>
-        <location filename="../../zuluMount-gui/keydialog.cpp" line="454"/>
-        <location filename="../../zuluMount-gui/keydialog.cpp" line="463"/>
-        <location filename="../../zuluMount-gui/keydialog.cpp" line="579"/>
-        <location filename="../../zuluMount-gui/keydialog.cpp" line="598"/>
+        <location filename="../../zuluMount-gui/keydialog.cpp" line="391"/>
+        <location filename="../../zuluMount-gui/keydialog.cpp" line="432"/>
+        <location filename="../../zuluMount-gui/keydialog.cpp" line="474"/>
+        <location filename="../../zuluMount-gui/keydialog.cpp" line="479"/>
+        <location filename="../../zuluMount-gui/keydialog.cpp" line="488"/>
+        <location filename="../../zuluMount-gui/keydialog.cpp" line="609"/>
+        <location filename="../../zuluMount-gui/keydialog.cpp" line="628"/>
         <source>ERROR</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/keydialog.cpp" line="579"/>
+        <location filename="../../zuluMount-gui/keydialog.cpp" line="609"/>
         <source>An error has occured and the volume could not be opened</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/keydialog.cpp" line="70"/>
+        <location filename="../../zuluMount-gui/keydialog.cpp" line="71"/>
         <source>Mount A LUKS volume in &quot;%1&quot;</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <location filename="../../zuluMount-gui/keydialog.cpp" line="124"/>
-        <source>Set File System Options</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="../../zuluMount-gui/keydialog.cpp" line="125"/>
         <location filename="../../zuluMount-gui/keydialog.cpp" line="215"/>
-        <source>Set Volume Offset</source>
+        <source>Set File System Options</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../../zuluMount-gui/keydialog.cpp" line="126"/>
         <location filename="../../zuluMount-gui/keydialog.cpp" line="217"/>
+        <source>Set Volume Offset</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../zuluMount-gui/keydialog.cpp" line="127"/>
+        <location filename="../../zuluMount-gui/keydialog.cpp" line="219"/>
         <source>Set Volume As VeraCrypt Volume</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/keydialog.cpp" line="137"/>
+        <location filename="../../zuluMount-gui/keydialog.cpp" line="139"/>
         <source>TrueCrypt/VeraCrypt Keys</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/keydialog.cpp" line="139"/>
+        <location filename="../../zuluMount-gui/keydialog.cpp" line="141"/>
         <source>TrueCrypt keys</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/keydialog.cpp" line="129"/>
+        <location filename="../../zuluMount-gui/keydialog.cpp" line="131"/>
         <source>Keyfile</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/keydialog.cpp" line="130"/>
+        <location filename="../../zuluMount-gui/keydialog.cpp" line="128"/>
+        <location filename="../../zuluMount-gui/keydialog.cpp" line="221"/>
+        <source>Set VeraCrypt PIM value</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../zuluMount-gui/keydialog.cpp" line="132"/>
         <source>Plugin</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/keydialog.cpp" line="213"/>
-        <source>Set File System 0ptions</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../zuluMount-gui/keydialog.cpp" line="244"/>
+        <location filename="../../zuluMount-gui/keydialog.cpp" line="259"/>
         <source>Select A Folder To Create A Mount Point In</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/keydialog.cpp" line="294"/>
+        <location filename="../../zuluMount-gui/keydialog.cpp" line="309"/>
         <source>Select A File To Be Used As A Keyfile</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/keydialog.cpp" line="319"/>
-        <location filename="../../zuluMount-gui/keydialog.cpp" line="326"/>
+        <location filename="../../zuluMount-gui/keydialog.cpp" line="334"/>
+        <location filename="../../zuluMount-gui/keydialog.cpp" line="341"/>
         <source>Cancel</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/keydialog.cpp" line="359"/>
+        <location filename="../../zuluMount-gui/keydialog.cpp" line="374"/>
         <source>ERROR!</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/keydialog.cpp" line="359"/>
+        <location filename="../../zuluMount-gui/keydialog.cpp" line="374"/>
         <source>Internal wallet is not configured</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/keydialog.cpp" line="376"/>
+        <location filename="../../zuluMount-gui/keydialog.cpp" line="391"/>
         <source>The volume does not appear to have an entry in the wallet</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/keydialog.cpp" line="449"/>
+        <location filename="../../zuluMount-gui/keydialog.cpp" line="474"/>
         <source>Plug in name field is empty</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/keydialog.cpp" line="454"/>
+        <location filename="../../zuluMount-gui/keydialog.cpp" line="479"/>
         <source>Keyfile field is empty</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/keydialog.cpp" line="623"/>
+        <location filename="../../zuluMount-gui/keydialog.cpp" line="653"/>
         <source>Plugin name</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/keydialog.cpp" line="643"/>
+        <location filename="../../zuluMount-gui/keydialog.cpp" line="673"/>
         <source>Keyfile path</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/keydialog.cpp" line="463"/>
+        <location filename="../../zuluMount-gui/keydialog.cpp" line="488"/>
         <source>&quot;/&quot; character is not allowed in the mount name field</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/keydialog.cpp" line="72"/>
+        <location filename="../../zuluMount-gui/keydialog.cpp" line="73"/>
         <source>Mount An Encrypted Volume In &quot;%1&quot;</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/keydialog.cpp" line="407"/>
+        <location filename="../../zuluMount-gui/keydialog.cpp" line="432"/>
         <source>Failed to unlock an encfs volume.
 Wrong password or not an encfs volume</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/keydialog.cpp" line="594"/>
+        <location filename="../../zuluMount-gui/keydialog.cpp" line="624"/>
         <source>ERROR: </source>
         <translation type="unfinished"></translation>
     </message>
@@ -658,34 +698,34 @@ Wrong password or not an encfs volume</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/mountpartition.cpp" line="84"/>
-        <location filename="../../zuluMount-gui/mountpartition.cpp" line="235"/>
+        <location filename="../../zuluMount-gui/mountpartition.cpp" line="82"/>
+        <location filename="../../zuluMount-gui/mountpartition.cpp" line="233"/>
         <source>Set File System Options</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/mountpartition.cpp" line="85"/>
+        <location filename="../../zuluMount-gui/mountpartition.cpp" line="83"/>
         <source>Set Volume Offset</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/mountpartition.cpp" line="156"/>
-        <location filename="../../zuluMount-gui/mountpartition.cpp" line="212"/>
+        <location filename="../../zuluMount-gui/mountpartition.cpp" line="154"/>
+        <location filename="../../zuluMount-gui/mountpartition.cpp" line="210"/>
         <source>ERROR</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/mountpartition.cpp" line="156"/>
+        <location filename="../../zuluMount-gui/mountpartition.cpp" line="154"/>
         <source>&quot;/&quot; character is not allowed in the mount name field</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/mountpartition.cpp" line="209"/>
+        <location filename="../../zuluMount-gui/mountpartition.cpp" line="207"/>
         <source>ERROR: </source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/mountpartition.cpp" line="249"/>
+        <location filename="../../zuluMount-gui/mountpartition.cpp" line="247"/>
         <source>Select Path To Mount Point Folder</source>
         <translation type="unfinished"></translation>
     </message>
@@ -693,12 +733,12 @@ Wrong password or not an encfs volume</source>
 <context>
     <name>oneinstance</name>
     <message>
-        <location filename="../../zuluMount-gui/oneinstance.cpp" line="51"/>
+        <location filename="../../zuluMount-gui/oneinstance.cpp" line="115"/>
         <source>There seem to be another instance running,exiting this one</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/oneinstance.cpp" line="54"/>
+        <location filename="../../zuluMount-gui/oneinstance.cpp" line="108"/>
         <source>Previous instance seem to have crashed,trying to clean up before starting</source>
         <translation type="unfinished"></translation>
     </message>
@@ -706,22 +746,22 @@ Wrong password or not an encfs volume</source>
 <context>
     <name>utility::veraCryptWarning</name>
     <message>
-        <location filename="../../zuluCrypt-gui/utility.h" line="357"/>
+        <location filename="../../zuluCrypt-gui/utility.h" line="416"/>
         <source>Elapsed time: 0 seconds</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../zuluCrypt-gui/utility.h" line="365"/>
+        <location filename="../../zuluCrypt-gui/utility.h" line="424"/>
         <source>Elapsed time: %0 minutes</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../zuluCrypt-gui/utility.h" line="367"/>
+        <location filename="../../zuluCrypt-gui/utility.h" line="426"/>
         <source>Elapsed time: %0 seconds</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../zuluCrypt-gui/utility.h" line="378"/>
+        <location filename="../../zuluCrypt-gui/utility.h" line="437"/>
         <source>Please be patient as unlocking a VeraCrypt volume may take a very long time.
 
 </source>
