@@ -1,6 +1,6 @@
  /*
  *
- *  Copyright (c) 2012
+ *  Copyright (c) 2012-2015
  *  name : Francis Banyikwa
  *  email: mhogomchungu@gmail.com
  *  This program is free software: you can redistribute it and/or modify
@@ -33,7 +33,7 @@ static void _remove_mapper( const char * path,stringList_t stl,uid_t uid )
 	/*
 	 * zuluCryptBindUnmountVolume() is defined in ./bind.c
 	 */
-	int r = zuluCryptBindUnmountVolume( stl,path,uid )  ;
+	int r = zuluCryptBindUnmountVolume( stl,path,uid ) ;
 
 	if( r == 3 || r == 4 ){
 		/*
@@ -47,11 +47,10 @@ static void _remove_mapper( const char * path,stringList_t stl,uid_t uid )
 	 */
 	r = zuluCryptCloseVolume( path,&m_point ) ;
 
-	if( r == 0 ){
-		if( m_point != NULL ){
-			remove( m_point ) ;
-			StringFree( m_point ) ;
-		}
+	if( r == 0 && m_point != NULL ){
+
+		remove( m_point ) ;
+		StringFree( m_point ) ;
 	}
 }
 
@@ -63,6 +62,9 @@ void zuluCryptClearDeadMappers( uid_t uid )
 	struct dirent * entry ;
 	const char * m ;
 	const char * e ;
+
+	char * r ;
+
 	size_t len ;
 	size_t len1 ;
 
@@ -103,24 +105,38 @@ void zuluCryptClearDeadMappers( uid_t uid )
 			if( zuluCryptTrueCryptOrVeraCryptVolume( e ) ){
 
 				/*
-				 * Below code seems to only work with cryptsetup created mappers
+				 * zuluCryptVolumeDeviceName() is defined in ../lib/status.c
 				 */
-				continue ;
-			}
-			if( crypt_init_by_name( &cd,e ) == 0 ){
+				r = zuluCryptVolumeDeviceName( e ) ;
+
+				if( *( r + 0 ) != '/' ){
 
-				if( crypt_get_device_name( cd ) == NULL ){
 					/*
-					 * we will get here if none LUKS mapper is active but the underlying device is gone
+					 * tcplay seems to report device name as something like "8:33"
+					 * when a mapper exists but its underlying device is gone and we exploit
+					 * this behavior by checking if path starts with "/" and we assume the
+					 * device is gone if it isnt.
 					 */
 					_remove_mapper( e,stl,uid ) ;
 				}
-				crypt_free( cd ) ;
+
+				StringFree( r ) ;
 			}else{
-				/*
-				 * we will get here if the LUKS mapper is active but the underlying device is gone
-				 */
-				_remove_mapper( e,stl,uid ) ;
+				if( crypt_init_by_name( &cd,e ) == 0 ){
+
+					if( crypt_get_device_name( cd ) == NULL ){
+						/*
+						* we will get here if none LUKS mapper is active but the underlying device is gone
+						*/
+						_remove_mapper( e,stl,uid ) ;
+					}
+					crypt_free( cd ) ;
+				}else{
+					/*
+					* we will get here if the LUKS mapper is active but the underlying device is gone
+					*/
+					_remove_mapper( e,stl,uid ) ;
+				}
 			}
 		}
 	}
