@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright ( c ) 2012
+ *  Copyright ( c ) 2012-2015
  *  name : Francis Banyikwa
  *  email: mhogomchungu@gmail.com
  *  This program is free software: you can redistribute it and/or modify
@@ -23,11 +23,14 @@
 
 void zuluCryptEXEGetOptsSetDefault( struct_opts * stopts )
 {
+	static char random[] = "/dev/urandom" ;
+	static char type[]   = "luks" ;
+
 	memset( stopts,'\0',sizeof( struct_opts ) ) ;
 
-	stopts->fs = "ext4" ;
-	stopts->type = "luks" ;
-	stopts->rng = "/dev/urandom" ;
+	stopts->fs   = "ext4" ;
+	stopts->rng  = random ;
+	stopts->type = type ;
 
 	stopts->open_mount = 1 ;
 	stopts->ask_confirmation = 1 ;
