@@ -1,6 +1,6 @@
  /*
   *
-  *  Copyright (c) 2011
+  *  Copyright (c) 2011-2015
   *  name : Francis Banyikwa
   *  email: mhogomchungu@gmail.com
   *  This program is free software: you can redistribute it and/or modify
@@ -34,6 +34,13 @@
 #include "locale_path.h"
 #include "../lib/includes.h"
 
+typedef struct{
+
+	int iteration_count ;
+	string_t type ;
+
+}tvcrypt ;
+
 /*
  * these two defines are used in save_and_restore_volume_header.c
  */
@@ -50,6 +57,11 @@
  */
 extern uid_t global_variable_user_uid ;
 
+/*
+ * zuluCryptTrueCryptVeraCryptVolumeInfo() is defined in open_volume.c
+ */
+void zuluCryptTrueCryptVeraCryptVolumeInfo( const char * type,tvcrypt * e ) ;
+
 /*
  * this function is defined in security.c
  */
@@ -111,11 +123,6 @@ int zuluCryptSecurityCheckPartitionPermissions( uid_t uid ) ;
  */
 char * zuluCryptDeviceFromLabel( const char * label ) ;
 
-/*
- * this function is defined in security.c
- */
-int zuluCryptUserIsAMemberOfAGroup( uid_t uid,const char * groupname ) ;
-
 /*
  * this function is defined in security.c
  */
