@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright ( c ) 2011
+ *  Copyright ( c ) 2011-2015
  *  name : Francis Banyikwa
  *  email: mhogomchungu@gmail.com
  *  This program is free software: you can redistribute it and/or modify
@@ -30,6 +30,16 @@
 #include <unistd.h>
 #include <grp.h>
 
+static void _seteuid( uid_t uid )
+{
+	if( seteuid( uid ) ){;}
+}
+
+static void _setuid( uid_t uid )
+{
+	if( setuid( uid ) ){;}
+}
+
 static int zuluCryptEXEGetDevice( const char * device )
 {
 	/*
@@ -330,7 +340,7 @@ int main( int argc,char * argv[] )
 	/*
 	 * setgroups() requires seteuid(0) ;
 	 */
-	seteuid( 0 ) ;
+	_seteuid( 0 ) ;
 	if( setgroups( 1,&gid ) != 0 ){
 		_privilegeEvelationError( gettext( "ERROR: setgroups() failed" ) ) ;
 	}
@@ -367,8 +377,8 @@ int main( int argc,char * argv[] )
 	 */
 	setpriority( PRIO_PROCESS,0,-15 ) ;
 
-	setuid( 0 ) ;
-	seteuid( uid ) ;
+	_setuid( 0 ) ;
+	_seteuid( uid ) ;
 
 	/*
 	 * zuluCryptSetUserUIDForPrivilegeManagement() is defined in ./security.c
@@ -465,7 +475,16 @@ int main( int argc,char * argv[] )
 		hide( clargs.device ) ;
 		clargs.device = StringContent( q ) ;
 	}
-
+	if( clargs.type != NULL ){
+		q = StringListAssignString( stl,String( clargs.type ) ) ;
+		hide( clargs.type ) ;
+		clargs.type = StringContent( q ) ;
+	}
+	if( clargs.rng != NULL ){
+		q = StringListAssignString( stl,String( clargs.rng ) ) ;
+		hide( clargs.rng ) ;
+		clargs.rng = StringContent( q ) ;
+	}
 	for( i = 0 ; clargs.tcrypt_multiple_keyfiles[ i ] != NULL ; i++ ){
 
 		q = StringListAssignString( stl,String( clargs.tcrypt_multiple_keyfiles[ i ] ) ) ;
@@ -485,6 +504,13 @@ int main( int argc,char * argv[] )
 	action = clargs.action ;
 	device = clargs.device ;
 
+	if( action == 'C' ){
+
+		return zuluExit( _clear_dead_mappers( uid ),stl,stx,env,NULL ) ;
+	}else{
+		_clear_dead_mappers( uid ) ;
+	}
+
 	/*
 	 * below tests are here because they do not use -d option
 	 *
@@ -492,7 +518,6 @@ int main( int argc,char * argv[] )
 	 * zuluCryptSecurityCheckPartitionPermissions() is defined in security.c
 	 */
 	switch( action ){
-		case 'C': return zuluExit( _clear_dead_mappers( uid ),stl,stx,env,NULL ) ;
 		case 'A':
 		case 'N':
 		case 'S': st = zuluCryptPrintPartitions( clargs.partition_number,clargs.print_partition_type,uid ) ;
@@ -501,8 +526,6 @@ int main( int argc,char * argv[] )
 			  return zuluExit( st,stl,stx,env,NULL ) ;
 	}
 
-	_clear_dead_mappers( uid ) ;
-
 	if( action == '\0' ){
 		return zuluExit( 130,stl,stx,env,gettext( "ERROR: \"action\" argument is missing" ) ) ;
 	}
