@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (c) 2011
+ *  Copyright (c) 2011-2015
  *  name : Francis Banyikwa
  *  email: mhogomchungu@gmail.com
  *  This program is free software: you can redistribute it and/or modify
@@ -205,9 +205,33 @@ static int _open_volume( const open_struct_t * volume )
 	return r ;
 }
 
+void zuluCryptTrueCryptVeraCryptVolumeInfo( const char * type,tvcrypt * e )
+{
+	stringList_t stl = StringListSplit( type,'.' ) ;
+
+	size_t p = StringListSize( stl ) ;
+
+	const char * q ;
+
+	memset( e,'\0',sizeof( tvcrypt ) ) ;
+
+	if( p > 0 ){
+
+		e->type = StringListCopyStringAtFirstPlace( stl ) ;
+
+		if( p > 1 ){
+
+			q = StringListContentAtSecondPlace( stl ) ;
+
+			e->iteration_count = ( int )StringConvertToInt( q ) ;
+		}
+	}
+
+	StringListDelete( &stl ) ;
+}
+
 int zuluCryptEXEOpenVolume( const struct_opts * opts,const char * mapping_name,uid_t uid )
 {
-	int veraCrypt_volume = StringAtLeastOneMatch_1( opts->type,"vcrypt","veracrypt","vera",NULL ) ;
 	int share                = opts->share ;
 	int open_mount           = opts->open_mount ;
 	const char * device      = opts->device ;
@@ -234,8 +258,6 @@ int zuluCryptEXEOpenVolume( const struct_opts * opts,const char * mapping_name,u
 	string_t * mapper      =  &stringArray[ 4 ] ;
 	string_t * mapper_path =  &stringArray[ 5 ] ;
 
-	stringList_t stz = StringListVoid ;
-
 	const char * key = NULL ;
 	const char * mapper_name ;
 	const char * e ;
@@ -243,6 +265,9 @@ int zuluCryptEXEOpenVolume( const struct_opts * opts,const char * mapping_name,u
 	size_t key_len = 0 ;
 	int st = 0 ;
 
+	stringList_t stz ;
+	tvcrypt v_info ;
+
 	unsigned long m_flags ;
 
 	int tcrypt_keyfile  = 0 ;
@@ -428,7 +453,17 @@ int zuluCryptEXEOpenVolume( const struct_opts * opts,const char * mapping_name,u
 	volume.uid         = uid ;
 	volume.m_opts      = m_opts ;
 	volume.m_flags     = m_flags ;
-	volume.veraCrypt_volume = veraCrypt_volume ;
+
+	/*
+	 * zuluCryptTrueCryptVeraCryptVolumeInfo() is defined in this source file.
+	 */
+	zuluCryptTrueCryptVeraCryptVolumeInfo( opts->type,&v_info ) ;
+
+	volume.iteration_count = v_info.iteration_count ;
+
+	volume.veraCrypt_volume = StringAtLeastOneMatch( v_info.type,"vcrypt","veracrypt","vera",NULL ) ;
+
+	StringDelete( &v_info.type ) ;
 
 	plugin_path = plugin_path + StringLastIndexOfChar_1( plugin_path,'/' ) + 1 ;
 
