@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (c) 2011
+ *  Copyright (c) 2011-2015
  *  name : Francis Banyikwa
  *  email: mhogomchungu@gmail.com
  *  This program is free software: you can redistribute it and/or modify
@@ -44,7 +44,7 @@ static int _zuluCryptExECheckEmptySlots( const char * device )
 		}
 	}
 
-	free( c ) ;
+	StringFree( c ) ;
 
 	return status ;
 }
