@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (c) 2012
+ *  Copyright (c) 2012-2015
  *  name : Francis Banyikwa
  *  email: mhogomchungu@gmail.com
  *  This program is free software: you can redistribute it and/or modify
@@ -39,7 +39,7 @@
  * A successfully constructed "ZULUCRYPTshortMapperPath mapper path" will look like "zuluCrypt-500-NAAN-mdraid-2355849641"
  */
 
-static string_t _create( const char * device,const char * mapping_name,uid_t uid,int i )
+string_t zuluCryptCreateMapperName( const char * device,const char * mapping_name,uid_t uid,int i )
 {
 	string_t p ;
 	unsigned long z ;
@@ -94,11 +94,6 @@ static string_t _create( const char * device,const char * mapping_name,uid_t uid
 	return p ;
 }
 
-string_t zuluCryptCreateMapperName( const char * device,const char * mapping_name,uid_t uid,int i )
-{
-	return _create( device,mapping_name,uid,i ) ;
-}
-
 static const char * _zuluCryptMapperPrefix = NULL ;
 
 const char * zuluCryptMapperPrefix( void )
