@@ -1,7 +1,7 @@
 
  /*
   *
-  *  Copyright (c) 2013
+  *  Copyright (c) 2013-2015
   *  name : Francis Banyikwa
   *  email: mhogomchungu@gmail.com
   *  This program is free software: you can redistribute it and/or modify
@@ -36,7 +36,7 @@
 static const int TRUE  = 1 ;
 static const int FALSE = 0 ;
 
-static int _create_file_system( const create_tcrypt_t * e )
+static int _create_file_system( const create_tcrypt_t * e,int iteration_count )
 {
 	string_t m = StringVoid ;
 
@@ -52,7 +52,7 @@ static int _create_file_system( const create_tcrypt_t * e )
 	memset( &opts,'\0',sizeof( open_struct_t ) ) ;
 
 	m = String( crypt_get_dir() ) ;
-	len = StringLength( m )   ;
+	len = StringLength( m ) ;
 
 	StringAppend( m,"/zuluCrypt-" ) ;
 	device_mapper = StringAppendInt( m,syscall( SYS_gettid ) ) ;
@@ -72,6 +72,7 @@ static int _create_file_system( const create_tcrypt_t * e )
 	}
 
 	opts.veraCrypt_volume = e->veraCrypt_volume ;
+	opts.iteration_count  = iteration_count ;
 
 	/*
 	 * zuluCryptOpenTcrypt_1 is defined in open_tcrypt.c
@@ -161,7 +162,7 @@ static string_t _root_device( const char * device,const char ** sys_device )
 	return st ;
 }
 
-static int _modify_tcrypt_header( const char * device,const info_t * info )
+static int _modify_tcrypt_header( const char * device,const resolve_path_t * opts )
 {
 	tc_api_task task ;
 
@@ -169,6 +170,8 @@ static int _modify_tcrypt_header( const char * device,const info_t * info )
 
 	const char * sys_device = NULL ;
 
+	const info_t * info = opts->args ;
+
 	string_t st = StringVoid ;
 
 	if( info->device == NULL ){
@@ -176,9 +179,7 @@ static int _modify_tcrypt_header( const char * device,const info_t * info )
 	}
 	if( tc_api_initialize() ){
 
-		task = tc_api_task_init( "modify" ) ;
-
-		if( tc_api_task_initialized( task ) ){
+		if( tc_api_task_initialize( &task,"modify" ) ){
 
 			if( StringsAreEqual( info->opt,"sys" ) ){
 
@@ -197,33 +198,9 @@ static int _modify_tcrypt_header( const char * device,const info_t * info )
 			}
 
 			tc_api_task_set( task,"hidden_size_bytes",( u_int64_t )0 ) ;
-
-			if( info->header_source && info->tmp_path ){
-				/*
-				* below line may look like one of the following two lines:
-				* tc_api_task_set( task,"header_from_file","/home/ink/tc.headerbackup" ) ;
-				* tc_api_task_set( task,"save_header_to_file","/home/ink/tc.headerbackup" ) ;
-				*/
-				tc_api_task_set( task,info->header_source,info->tmp_path ) ;
-			}
-
-			if( info->header_key_source && info->header_key ){
-				/*
-				* below line may look like one of the following two lines:
-				* tc_api_task_set( task,"passphrase","xxx" ) ;
-				* tc_api_task_set( task,"keyfiles","/home/ink/keyfile" ) ;
-				*/
-				tc_api_task_set( task,info->header_key_source,info->header_key ) ;
-			}
-
-			if( info->header_new_key_source && info->header_new_key ){
-				/*
-				* below line may look like one of the following two lines:
-				* tc_api_task_set( task,"new_passphrase","xxx" ) ;
-				* tc_api_task_set( task,"new_keyfiles","/home/ink/keyfile" ) ;
-				*/
-				tc_api_task_set( task,info->header_new_key_source,info->header_new_key ) ;
-			}
+			tc_api_task_set( task,info->header_source,info->tmp_path ) ;
+			tc_api_task_set( task,info->header_key_source,info->header_key ) ;
+			tc_api_task_set( task,info->header_new_key_source,info->header_new_key ) ;
 
 			tc_api_task_set( task,"weak_keys_and_salt",StringsAreEqual( info->rng,"/dev/urandom" ) ) ;
 
@@ -238,33 +215,27 @@ static int _modify_tcrypt_header( const char * device,const info_t * info )
 	return r ;
 }
 
-int zuluCryptModifyTcryptHeader( const info_t * e )
+int zuluCryptModifyTcryptHeader( const info_t * info )
 {
-	int fd ;
-	string_t q = StringVoid ;
-	int r ;
+	/*
+	 * resolve_path_t is defined in includes.h
+	 */
+	resolve_path_t opts ;
 
-	if( StringPrefixEqual( e->device,"/dev/" ) ){
+	memset( &opts,'\0',sizeof( resolve_path_t ) ) ;
 
-		r = _modify_tcrypt_header( e->device,e ) ;
-	}else{
-		/*
-		 * zuluCryptAttachLoopDeviceToFile() is defined in create_loop_device.c
-		 */
-		if( zuluCryptAttachLoopDeviceToFile( e->device,O_RDWR,&fd,&q ) ){
+	opts.device      = info->device ;
+	opts.args        = info ;
+	opts.error_value = 3 ;
+	opts.open_mode   = O_RDWR ;
 
-			r = _modify_tcrypt_header( StringContent( q ),e ) ;
-			StringDelete( &q ) ;
-			close( fd ) ;
-		}else{
-			r = 3 ;
-		}
-	}
-
-	return r ;
+	/*
+	 * zuluCryptResolveDevicePath() is defined in resolve_path.c
+	 */
+	return zuluCryptResolveDevicePath( _modify_tcrypt_header,&opts ) ;
 }
 
-struct{
+static const struct{
 	const char * first ;
 	const char * second;
 } pair[] = {
@@ -362,6 +333,20 @@ static int _zuluExit( int r,char * const * options,stringList_t stl )
 	return r ;
 }
 
+int zuluCryptVeraCryptPIM( int pim )
+{
+	if( pim > 0 ){
+		return 15000 + ( pim * 1000 ) ;
+	}else{
+		return 0 ;
+	}
+}
+
+int zuluCryptSystemVeraCryptPIM( int pim )
+{
+	return pim * 2048 ;
+}
+
 /*
  * e->encryption_options will contain a structure in the following format:
  * rng.algorithm.cipher mode.key size in bits.hash function
@@ -375,7 +360,7 @@ static int _zuluExit( int r,char * const * options,stringList_t stl )
  *
  * key size field and cipher mode field are currently not in use
  */
-static int _create_tcrypt_volume( const char * device,const create_tcrypt_t * e )
+static int _create_tcrypt_volume( const char * device,const resolve_path_t * opts )
 {
 	tc_api_task task ;
 	int r = !TC_OK ;
@@ -390,12 +375,11 @@ static int _create_tcrypt_volume( const char * device,const create_tcrypt_t * e
 	char * const * options = NULL ;
 	size_t options_count = 0 ;
 
+	int iteration_count = 0 ;
+
 	stringList_t stl ;
 
-	if( e->veraCrypt_volume && !VERACRYPT_CREATE ){
-
-		return !TC_OK ;
-	}
+	const create_tcrypt_t * e = opts->args ;
 
 	if( StringHasNothing( e->encryption_options ) ){
 
@@ -418,26 +402,31 @@ static int _create_tcrypt_volume( const char * device,const create_tcrypt_t * e
 			hash = "RIPEMD160" ;
 		}
 
-	}else if( options_count == 5 ){
+	}else if( options_count >= 5 ){
 
 		cipher_chain = _set_cipher_chain( options + 1 ) ;
 		hash         = _set_hash( options + 4 ) ;
 		rng          = *( options + 0 ) ;
 
 		if( cipher_chain == NULL || hash == NULL ){
+
 			return _zuluExit( !TC_OK,options,stl ) ;
 		}
+
+		if( options_count >= 6 ){
+
+			iteration_count = ( int )StringConvertToInt( *( options + 5 ) ) ;
+		}
 	}else{
 		return _zuluExit( !TC_OK,options,stl ) ;
 	}
 
 	if( tc_api_initialize() ){
 
-		task = tc_api_task_init( "create" ) ;
-
-		if( tc_api_task_initialized( task ) ){
+		if( tc_api_task_initialize( &task,"create" ) ){
 
 			tc_api_task_set( task,"veracrypt_mode",e->veraCrypt_volume ) ;
+			tc_api_task_set( task,"iteration_count",zuluCryptVeraCryptPIM( iteration_count ) ) ;
 			tc_api_task_set( task,"dev",device ) ;
 			tc_api_task_set( task,"secure_erase",FALSE ) ;
 			tc_api_task_set( task,"prf_algo",hash ) ;
@@ -472,7 +461,7 @@ static int _create_tcrypt_volume( const char * device,const create_tcrypt_t * e
 			tc_api_task_uninit( task ) ;
 
 			if( r == TC_OK ){
-				r = _create_file_system( e ) ;
+				r = _create_file_system( e,iteration_count ) ;
 			}
 		}
 
@@ -482,30 +471,24 @@ static int _create_tcrypt_volume( const char * device,const create_tcrypt_t * e
 	return _zuluExit( r,options,stl ) ;
 }
 
-int zuluCryptCreateTCryptVolume( const create_tcrypt_t * e )
+int zuluCryptCreateTCryptVolume( const create_tcrypt_t * tcrypt )
 {
-	int fd ;
-	string_t q = StringVoid ;
-	int r ;
+	/*
+	 * resolve_path_t is defined in includes.h
+	 */
+	resolve_path_t opts ;
 
-	if( StringPrefixEqual( e->device,"/dev/" ) ){
+	memset( &opts,'\0',sizeof( resolve_path_t ) ) ;
 
-		r = _create_tcrypt_volume( e->device,e ) ;
-	}else{
-		/*
-		 * zuluCryptAttachLoopDeviceToFile() is defined in create_loop_device.c
-		 */
-		if( zuluCryptAttachLoopDeviceToFile( e->device,O_RDWR,&fd,&q ) ){
+	opts.device      = tcrypt->device ;
+	opts.args        = tcrypt ;
+	opts.error_value = 3 ;
+	opts.open_mode   = O_RDWR ;
 
-			r = _create_tcrypt_volume( StringContent( q ),e ) ;
-			StringDelete( &q ) ;
-			close( fd ) ;
-		}else{
-			r = 3 ;
-		}
-	}
-
-	return r ;
+	/*
+	 * zuluCryptResolveDevicePath() is defined in resolve_path.c
+	 */
+	return zuluCryptResolveDevicePath( _create_tcrypt_volume,&opts ) ;
 }
 
 int zuluCryptCreateTCrypt( const char * device,const char * file_system,const char * rng,
