@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (c) 2011
+ *  Copyright (c) 2011-2015
  *  name : Francis Banyikwa
  *  email: mhogomchungu@gmail.com
  *  This program is free software: you can redistribute it and/or modify
@@ -73,6 +73,7 @@ typedef struct{
 	uid_t        uid ;
 	int          volume_type ;
 	int          key_source ;
+	int iteration_count ;
 	int luks_detached_header ;
 	int tcrypt_keyfiles_count ;
 	int veraCrypt_volume ;
@@ -98,6 +99,14 @@ typedef struct{
 	int veraCrypt_volume ;
 }create_tcrypt_t ;
 
+typedef struct{
+	const char * device ;
+	int          error_value ;
+	char       * error_value_1 ;
+	int          open_mode ;
+	const void * args ;
+}resolve_path_t ;
+
 /*
  * we only support whirlpool with cryptsetup >= 1.6.4 and libgcrypt >= 1.6.1
  *
@@ -113,6 +122,33 @@ static inline int zuluCryptWhirlpoolIsSupported()
 #endif
 }
 
+/*
+ * zuluCryptVeraCryptPIM() is defined in create_tcrypt.c
+ */
+int zuluCryptVeraCryptPIM( int e ) ;
+
+/*
+ * zuluCryptSystemVeraCryptPIM() is defined in create_tcrypt.c
+ */
+int zuluCryptSystemVeraCryptPIM( int e ) ;
+
+/*
+ * zuluCryptResolveDevicePath() is defined in resolve_path.c
+ */
+int zuluCryptResolveDevicePath( int( * )( const char *,const resolve_path_t * ),
+				const resolve_path_t * ) ;
+
+/*
+ * zuluCryptResolveDevicePath_1() is defined in resolve_path.c
+ */
+char * zuluCryptResolveDevicePath_1( char *( * )( const char *,const resolve_path_t * ),
+				     const resolve_path_t * ) ;
+/*
+ * zuluCryptResolveDevicePath_0() is defined in resolve_path.c
+ */
+int zuluCryptResolveDevicePath_0( int( * )( const char *,const resolve_path_t * ),
+				  const open_struct_t *,int ) ;
+
 /*
  * zuluCryptCreateTCryptVolume() is defined in create_tcrypt.c
  */
@@ -262,6 +298,11 @@ int zuluCryptAttachLoopDeviceToFile( const char * path,int mode,int * fd,string_
  */
 string_t zuluCryptGetFileSystemFromDevice( const char * device ) ;
 
+/*
+ * this function is defined in ./blkid_evaluate_tag.c
+ */
+int zuluCryptDeviceHasEncryptedFileSystem( const char * device ) ;
+
 /*
  * this function is defined in ./blkid_evaluate_tag.c
  */
@@ -512,4 +553,9 @@ stringList_t zuluCryptGetAListOfMountedVolumes( void ) ;
  */
 int zuluCryptModifyTcryptHeader( const info_t * info ) ;
 
+/*
+ * this function is defined in mount_fs_options.c
+ */
+int zuluCryptUserIsAMemberOfAGroup( uid_t uid,const char * groupname ) ;
+
 #endif
