@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (c) 2012
+ *  Copyright (c) 2012-2015
  *  name : Francis Banyikwa
  *  email: mhogomchungu@gmail.com
  *  This program is free software: you can redistribute it and/or modify
@@ -29,6 +29,23 @@
 #include "tcplay_support.h"
 #include "check_tcrypt.h"
 
+static void _chown( const char * x,uid_t y,gid_t z )
+{
+	if( chown( x,y,z ) ){;}
+}
+static void _chmod( const char * x,mode_t y )
+{
+	if( chmod( x,y ) ){;}
+}
+static void _write( int x,const void * y,size_t z )
+{
+	if( write( x,y,z ) ){;}
+}
+static void _close( int x )
+{
+	if( close( x ) ){;}
+}
+
 string_t zuluCryptCreateKeyFile( const char * key,size_t key_len,const char * fileName )
 {
 	string_t st = StringVoid ;
@@ -45,11 +62,11 @@ string_t zuluCryptCreateKeyFile( const char * key,size_t key_len,const char * fi
 
 	if( path_does_not_exist( "/run" ) ){
 		mkdir( "/run",S_IRWXU | S_IRGRP | S_IXGRP | S_IXOTH | S_IROTH ) ;
-		chown( "/run",0,0 ) ;
+		_chown( "/run",0,0 ) ;
 	}
 	if( path_does_not_exist( "/run/zuluCrypt" ) ){
 		mkdir( "/run/zuluCrypt",S_IRWXU ) ;
-		chown( "/run/zuluCrypt",0,0 ) ;
+		_chown( "/run/zuluCrypt",0,0 ) ;
 	}
 
 	st = String_1( "/run/zuluCrypt/",fileName,NULL ) ;
@@ -59,10 +76,10 @@ string_t zuluCryptCreateKeyFile( const char * key,size_t key_len,const char * fi
 	if( fd == -1 ){
 		StringDelete( &st ) ;
 	}else{
-		write( fd,key,key_len ) ;
-		close( fd ) ;
-		chown( file,0,0 ) ;
-		chmod( file,S_IRWXU ) ;
+		_write( fd,key,key_len ) ;
+		_close( fd ) ;
+		_chown( file,0,0 ) ;
+		_chmod( file,S_IRWXU ) ;
 	}
 
 	return st ;
@@ -73,13 +90,7 @@ string_t zuluCryptCreateKeyFile_1( string_t st,const char * fileName )
 	return zuluCryptCreateKeyFile( StringContent( st ),StringLength( st ),fileName ) ;
 }
 
-static inline int zuluExit( int st,struct crypt_device * cd )
-{
-	crypt_free( cd ) ;
-	return st ;
-}
-
-static int _open_tcrypt_volume( const char * device,const open_struct_t * opts )
+static int _open_tcrypt_volume( const char * device,const resolve_path_t * opt )
 {
 	tc_api_task task ;
 	int r = !TC_OK ;
@@ -91,44 +102,52 @@ static int _open_tcrypt_volume( const char * device,const open_struct_t * opts )
 
 	const char * e ;
 
+	/*
+	 * open_struct_t is defined in includes.h
+	 */
+	const open_struct_t * opts = opt->args ;
+
 	string_t st = StringVoid ;
 
 	if( tc_api_initialize() ){
 
-		task = tc_api_task_init( "map" ) ;
-
-		if( tc_api_task_initialized( task ) ){
+		if( tc_api_task_initialize( &task,"map" ) ){
 
 			tc_api_task_set( task,"veracrypt_mode",opts->veraCrypt_volume ) ;
 			tc_api_task_set( task,"map_name",opts->mapper_name ) ;
+			tc_api_task_set( task,"read_only",StringHasComponent( opts->m_opts,"ro" ) ) ;
 
-			if( StringHasComponent( opts->m_opts,"ro" ) ){
-
-				tc_api_task_set( task,"read_only" ) ;
-			}
+			tc_api_task_set( task,"dev",device ) ;
 
 			if( opts->tcrypt_system ){
 
-				if( StringPrefixEqual( device,"/dev/sd" ) ||
-					StringPrefixEqual( device,"/dev/hd" ) ){
+				/*
+				 * zuluCryptSystemVeraCryptPIM() is defined in create_tcrypt.c
+				 */
+				tc_api_task_set( task,"iteration_count",
+						 zuluCryptSystemVeraCryptPIM( opts->iteration_count ) ) ;
+
+				if( StringAtLeastOnePrefixMatch( device,"/dev/sd","/dev/hd",NULL ) ){
 
 					st = String( device ) ;
 					e = StringRemoveDigits( st ) ;
-					tc_api_task_set( task,"dev",e ) ;
 					tc_api_task_set( task,"sys",e ) ;
 				}else{
-					tc_api_task_set( task,"dev",device ) ;
 					tc_api_task_set( task,"sys",device ) ;
 				}
 			}else{
-				tc_api_task_set( task,"dev",device ) ;
+				/*
+				 * zuluCryptVeraCryptPIM() is defined in create_tcrypt.c
+				 */
+				tc_api_task_set( task,"iteration_count",
+						 zuluCryptVeraCryptPIM( opts->iteration_count ) ) ;
 			}
 
+			tc_api_task_set( task,"passphrase",opts->key ) ;
+
 			k = opts->tcrypt_keyfiles_count ;
 			z = opts->tcrypt_keyfiles ;
 
-			tc_api_task_set( task,"passphrase",opts->key ) ;
-
 			for( i = 0 ; i < k ; i++ ){
 				tc_api_task_set( task,"keyfiles",*( z + i ) ) ;
 			}
@@ -148,31 +167,10 @@ static int _open_tcrypt_volume( const char * device,const open_struct_t * opts )
 
 static int _open_tcrypt_0( const open_struct_t * opt )
 {
-	int mode ;
-	string_t st ;
-	int fd ;
-	int r ;
-
-	if( StringPrefixEqual( opt->device,"/dev/" ) ){
-		return _open_tcrypt_volume( opt->device,opt ) ;
-	}else{
-		if( StringHasComponent( opt->m_opts,"ro" ) ){
-			mode = O_RDONLY ;
-		}else{
-			mode = O_RDWR ;
-		}
-		/*
-		 * zuluCryptAttachLoopDeviceToFile() is defined in ./create_loop.c
-		 */
-		if( zuluCryptAttachLoopDeviceToFile( opt->device,mode,&fd,&st ) ){
-			r = _open_tcrypt_volume( StringContent( st ),opt ) ;
-			StringDelete( &st ) ;
-			close( fd ) ;
-			return r ;
-		}else{
-			return 1 ;
-		}
-	}
+	/*
+	 * zuluCryptResolveDevicePath_0() is defined in resolve_path.c
+	 */
+	return zuluCryptResolveDevicePath_0( _open_tcrypt_volume,opt,1 ) ;
 }
 
 int zuluCryptOpenTcrypt( const char * device,const char * mapper,const char * key,size_t key_len,
@@ -242,6 +240,12 @@ int zuluCryptOpenTcrypt_1( const open_struct_t * opts )
 }
 
 #if CHECK_TCRYPT
+
+static int zuluExit( int st,struct crypt_device * cd )
+{
+	crypt_free( cd ) ;
+	return st ;
+}
 /*
  * 1 is returned if a volume is a truecrypt volume.
  * 0 is returned if a volume is not a truecrypt volume or functionality is not supported
