@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (c) 2011
+ *  Copyright (c) 2011-2015
  *  name : Francis Banyikwa
  *  email: mhogomchungu@gmail.com
  *  This program is free software: you can redistribute it and/or modify
@@ -32,10 +32,6 @@
 
 #include "tcplay_support.h"
 
-/*
- * 64 byte buffer is more than enough because the API that will produce the largest number is crypt_get_data_offset()
- * and it produces a uint64_t number and this type has a maximum digit count is 19.
- */
 #define SIZE 1024
 
 #define TYPE 3
@@ -82,15 +78,7 @@ void zuluCryptFormatSize( u_int64_t number,char * buffer,size_t buffer_size )
 	}
 }
 
-/*
- * given a path of something like "/dev/mapper/zuluCrypt-500-NAAN-header-image-file.img-2244846319",
- * this routine will look for its corresponding entry in "/dev/disk/by-id/" and we will find
- * "dm-uuid-CRYPT-LUKS1-LUKS_UUID-zuluCrypt-500-NAAN-header-image-file.img-2244846319" and will
- * return desired component of the path when separated by "-" character.
- *
- */
-
-string_t _get_mapper_property_from_udev( const char * mapper,const char * prefix,size_t position )
+static string_t _get_mapper_property_from_udev( const char * mapper,const char * prefix,size_t position )
 {
 	DIR * dir = opendir( "/dev/disk/by-id/" ) ;
 	struct dirent * e ;
@@ -297,15 +285,13 @@ void zuluCryptFileSystemProperties( string_t p,const char * mapper,const char *
 
 int zuluCryptTrueCryptOrVeraCryptVolume( const char * mapper )
 {
-	int e ;
+	char buffer[ 1024 ] ;
 
-	char * f =  zuluCryptGetVolumeTypeFromMapperPath( mapper ) ;
+	mapper = mapper + StringLastIndexOfChar_1( mapper,'/' ) + 1 ;
 
-	e = StringsAreEqual( f,"crypto_TCRYPT" ) || StringsAreEqual( f,"crypto_VCRYPT" ) ;
+	tc_api_get_volume_type( buffer,sizeof( buffer ),mapper ) ;
 
-	StringFree( f ) ;
-
-	return e ;
+	return StringsAreEqual( buffer,"TCRYPT" ) || StringsAreEqual( buffer,"VCRYPT" ) ;
 }
 
 char * zuluCryptGetVolumeTypeFromMapperPath( const char * mapper )
@@ -348,173 +334,74 @@ char * zuluCryptGetVolumeTypeFromMapperPath( const char * mapper )
 	return r ;
 }
 
-static char * zuluExit( string_t st,struct crypt_device * cd,char * e )
+static void _device_info( string_t p,const char * device )
 {
-	StringFree( e ) ;
-	crypt_free( cd ) ;
-	return StringDeleteHandle( &st ) ;
-}
+	char * path ;
 
-static void _get_crypto_info_from_cryptsetup( string_t p,struct crypt_device * cd )
-{
-	char buff[ SIZE ] ;
-	char * buffer = buff ;
-	const char * z ;
+	if( device == NULL ){
 
-	uint64_t e ;
+		StringMultipleAppend( p,"\n device:   \t","Nil","\n loop:   \t","Nil",NULL ) ;
 
-	z = crypt_get_cipher( cd ) ;
+	}else if( StringPrefixEqual( device,"/dev/loop" ) ){
 
-	if( z != NULL ){
+		path = zuluCryptLoopDeviceAddress_1( device ) ;
 
-		StringMultipleAppend( p,"\n cipher:\t",z,"-",NULL ) ;
-	}else{
-		StringAppend( p,"\n cipher:\tNil-" ) ;
-	}
+		if( path != NULL ){
 
-	z = crypt_get_cipher_mode( cd ) ;
-
-	if( z != NULL ){
-
-		StringAppend( p,z ) ;
-	}else{
-		StringAppend( p,"Nil" ) ;
-	}
-
-	z = StringIntToString_1( buffer,SIZE,8 * crypt_get_volume_key_size( cd ) ) ;
-	StringMultipleAppend( p,"\n keysize:\t",z," bits",NULL ) ;
-
-	e = crypt_get_data_offset( cd ) ;
-
-	z = StringIntToString_1( buffer,SIZE,e ) ;
-	StringMultipleAppend( p,"\n offset:\t",z," sectors",NULL ) ;
-
-	zuluCryptFormatSize( e * 512,buffer,SIZE ) ;
-	StringMultipleAppend( p," / ",buffer,NULL ) ;
-}
-
-static int _get_crypto_info_from_tcplay( string_t p,const char * mapper )
-{
-	int key_size ;
-
-	int64_t offset ;
-
-	tc_api_task task ;
-
-	int r = 1 ;
-
-	char buff[ SIZE ] ;
-	char * buffer = buff ;
-
-	const char * z ;
-
-	if( tc_api_initialize() ){
-
-		task = tc_api_task_init( "info_mapped" ) ;
-
-		if( tc_api_task_initialized( task ) ){
-
-			mapper = mapper + StringLastIndexOfChar_1( mapper,'/' ) + 1 ;
-
-			tc_api_task_set( task,"map_name",mapper ) ;
-
-			tc_api_task_do( task ) ;
-
-			tc_api_task_info_get( task,"cipher",sizeof( buff ),buff ) ;
-
-			/*
-			 * zuluCryptConvertCipher() is defined in create_tcrypt.c
-			 */
-			StringMultipleAppend( p,"\n cipher:\t",zuluCryptConvertCipher( buff ),"-xts-plain64",NULL ) ;
-
-			tc_api_task_info_get( task,"key_bits",sizeof( key_size ),&key_size ) ;
-
-			z = StringIntToString_1( buffer,SIZE,key_size ) ;
-
-			StringMultipleAppend( p,"\n keysize:\t",z," bits",NULL ) ;
-
-			tc_api_task_info_get( task,"block_offset",sizeof( offset ),&offset ) ;
-
-			z = StringIntToString_1( buffer,SIZE,offset / 512 ) ;
-
-			StringMultipleAppend( p,"\n offset:\t",z," sectors",NULL ) ;
-
-			zuluCryptFormatSize( offset,buffer,SIZE ) ;
-
-			StringMultipleAppend( p," / ",buffer,NULL ) ;
-
-			tc_api_task_uninit( task ) ;
-
-			r = 0 ;
-		}
-
-		tc_api_uninit() ;
-	}
-
-	return r ;
-}
-
-static void _get_crypto_info( string_t p,struct crypt_device * cd,const char * mapper )
-{
-	if( zuluCryptTrueCryptOrVeraCryptVolume( mapper ) ){
-
-		if( _get_crypto_info_from_tcplay( p,mapper ) ){
-
-			_get_crypto_info_from_cryptsetup( p,cd ) ;
+			StringMultipleAppend( p,"\n device:   \t",device,"\n loop:   \t",path,NULL ) ;
+			StringFree( path ) ;
+		}else{
+			StringMultipleAppend( p,"\n device:   \t",device,"\n loop:   \tNil",NULL ) ;
 		}
 	}else{
-		_get_crypto_info_from_cryptsetup( p,cd ) ;
+		/*
+		 * zuluCryptResolvePath() is defined in resolve_path.c
+		 */
+		path = zuluCryptResolvePath( device ) ;
+		StringMultipleAppend( p,"\n device:   \t",path,"\n loop:   \tNil",NULL ) ;
+		StringFree( path ) ;
 	}
 }
 
-char * zuluCryptVolumeStatus( const char * mapper )
+static string_t _get_crypto_info_from_cryptsetup( const char * mapper )
 {
 	char buff[ SIZE ] ;
 	char * buffer = buff ;
 
 	const char * z ;
 	const char * type ;
-	char * path ;
-	int i ;
-	int j ;
-	int k ;
 
-	char * device_name = NULL ;
+	uint64_t e ;
+
+	string_t q ;
+	string_t p ;
+
+	int k ;
+	int i = 0 ;
+	int j ;
+
+	crypt_status_info info ;
 
 	struct crypt_device * cd ;
-	struct crypt_active_device cad ;
 
-	string_t p = StringVoid ;
-	string_t q ;
+	struct crypt_active_device cad ;
 
 	if( crypt_init_by_name( &cd,mapper ) != 0 ){
 
-		return NULL ;
-	}
-	if( crypt_get_active_device( NULL,mapper,&cad ) != 0 ){
-
-		return zuluExit( p,cd,device_name ) ;
-	}
-
-	/*
-	 * zuluCryptResolvePath_4() is defined in resolve_path.c
-	 */
-	device_name = _volume_device_name( mapper,zuluCryptResolvePath_4 ) ;
-
-	if( device_name == NULL ){
-
-		return zuluExit( p,cd,device_name ) ;
+		return StringVoid ;
 	}
 
 	p = String( mapper ) ;
 
-	switch( crypt_status( cd,mapper ) ){
+	info = crypt_status( cd,mapper ) ;
+
+	switch( info ){
 	case CRYPT_INACTIVE :
 		StringAppend( p," is inactive.\n" ) ;
-		return zuluExit( p,cd,device_name ) ;
+		break ;
 	case CRYPT_INVALID  :
 		StringAppend( p," is invalid.\n" ) ;
-		return zuluExit( p,cd,device_name ) ;
+		break ;
 	case CRYPT_ACTIVE   :
 		StringAppend( p," is active.\n" ) ;
 		break ;
@@ -523,112 +410,219 @@ char * zuluCryptVolumeStatus( const char * mapper )
 		break ;
 	default :
 		StringAppend( p," is invalid.\n" ) ;
-		return zuluExit( p,cd,device_name ) ;
 	}
 
-	StringAppend( p," type:   \t" ) ;
+	if( info == CRYPT_ACTIVE || info == CRYPT_BUSY ){
 
-	type = crypt_get_type( cd ) ;
+		StringAppend( p," type:   \t" ) ;
 
-	if( type != NULL ){
+		type = crypt_get_type( cd ) ;
 
-		q = String( type ) ;
-		StringAppend( p,StringToLowerCase( q ) ) ;
-		StringDelete( &q ) ;
+		if( type != NULL ){
+
+			q = String( type ) ;
+			StringAppend( p,StringToLowerCase( q ) ) ;
+			StringDelete( &q ) ;
+		}else{
+			q = _get_type_from_udev_1( mapper ) ;
+
+			StringAppendString( p,q ) ;
+
+			StringDelete( &q ) ;
+		}
+
+		z = crypt_get_cipher( cd ) ;
+
+		if( z != NULL ){
+
+			StringMultipleAppend( p,"\n cipher:\t",z,"-",NULL ) ;
+		}else{
+			StringAppend( p,"\n cipher:\tNil-" ) ;
+		}
+
+		z = crypt_get_cipher_mode( cd ) ;
+
+		if( z != NULL ){
+
+			StringAppend( p,z ) ;
+		}else{
+			StringAppend( p,"Nil" ) ;
+		}
+
+		z = StringIntToString_1( buffer,SIZE,8 * crypt_get_volume_key_size( cd ) ) ;
+		StringMultipleAppend( p,"\n keysize:\t",z," bits",NULL ) ;
+
+		e = crypt_get_data_offset( cd ) ;
+
+		z = StringIntToString_1( buffer,SIZE,e ) ;
+		StringMultipleAppend( p,"\n offset:\t",z," sectors",NULL ) ;
+
+		zuluCryptFormatSize( e * 512,buffer,SIZE ) ;
+		StringMultipleAppend( p," / ",buffer,NULL ) ;
+
+		_device_info( p,crypt_get_device_name( cd ) ) ;
+
+		crypt_get_active_device( NULL,mapper,&cad ) ;
+
+		if( cad.flags == 1 ){
+
+			StringAppend( p,"\n mode:   \tread only" ) ;
+		}else{
+			StringAppend( p,"\n mode:   \tread and write" ) ;
+		}
+
+		k = crypt_keyslot_max( crypt_get_type( cd ) ) ;
+
+		if( k > 0 ){
+
+			i = 0 ;
+
+			for( j = 0 ; j < k ; j++ ){
+
+				switch( crypt_keyslot_status( cd,j ) ){
+
+					case CRYPT_SLOT_ACTIVE_LAST : i++ ; break ;
+					case CRYPT_SLOT_ACTIVE      : i++ ; break ;
+					default : ;
+				}
+			}
+
+			StringMultipleAppend( p,"\n active slots:\t",StringIntToString_1( buffer,SIZE,i ),NULL ) ;
+
+			StringMultipleAppend( p," / ",StringIntToString_1( buffer,SIZE,k ),NULL ) ;
+		}else{
+			StringAppend( p,"\n active slots:\tNil" ) ;
+		}
+	}
+
+	crypt_free( cd ) ;
+
+	return p ;
+}
+
+static string_t _get_crypto_info_from_tcplay( const char * mapper )
+{
+	int key_size ;
+
+	int ro ;
+
+	int64_t offset ;
+
+	tc_api_task task ;
+
+	char buff[ SIZE ] ;
+	char * buffer = buff ;
+
+	const char * z ;
+
+	string_t p = StringVoid ;
+
+	string_t q ;
+
+	if( tc_api_initialize() ){
+
+		if( tc_api_task_initialize( &task,"info_mapped" ) ){
+
+			p = String( mapper ) ;
+
+			mapper = mapper + StringLastIndexOfChar_1( mapper,'/' ) + 1 ;
+
+			tc_api_task_set( task,"map_name",mapper ) ;
+
+			tc_api_task_do( task ) ;
+
+			tc_api_task_info_get( task,"status",sizeof( buff ),buff ) ;
+
+			StringMultipleAppend( p," is ",buff,".",NULL ) ;
+
+			if( StringAtLeastOneMatch_1( buff,"active","active and is in use",NULL ) ){
+
+				tc_api_task_info_get( task,"type",sizeof( buff ),buff ) ;
+
+				q = String( buff ) ;
+
+				StringMultipleAppend( p," \n type:   \t",StringToLowerCase( q ),NULL ) ;
+
+				StringDelete( &q ) ;
+
+				tc_api_task_info_get( task,"cipher",sizeof( buff ),buff ) ;
+
+				/*
+				 * zuluCryptConvertCipher() is defined in create_tcrypt.c
+				 */
+				StringMultipleAppend( p,"\n cipher:\t",zuluCryptConvertCipher( buff ),"-xts-plain64",NULL ) ;
+
+				tc_api_task_info_get( task,"key_bits",sizeof( key_size ),&key_size ) ;
+
+				z = StringIntToString_1( buffer,SIZE,key_size ) ;
+
+				StringMultipleAppend( p,"\n keysize:\t",z," bits",NULL ) ;
+
+				tc_api_task_info_get( task,"iv_offset",sizeof( offset ),&offset ) ;
+
+				z = StringIntToString_1( buffer,SIZE,offset / 512 ) ;
+
+				StringMultipleAppend( p,"\n offset:\t",z," sectors",NULL ) ;
+
+				zuluCryptFormatSize( offset,buffer,SIZE ) ;
+
+				StringMultipleAppend( p," / ",buffer,NULL ) ;
+
+				tc_api_task_info_get( task,"device",sizeof( buff ),buff ) ;
+
+				_device_info( p,buff ) ;
+
+				tc_api_task_info_get( task,"mode",sizeof( ro ),&ro ) ;
+
+				if( ro ){
+
+					StringAppend( p,"\n mode:   \tread only" ) ;
+				}else{
+					StringAppend( p,"\n mode:   \tread and write" ) ;
+				}
+
+				StringAppend( p,"\n active slots:\tNil" ) ;
+			}
+
+			tc_api_task_uninit( task ) ;
+		}
+
+		tc_api_uninit() ;
+	}
+
+	return p ;
+}
+
+char * zuluCryptVolumeStatus( const char * mapper )
+{
+	char * path ;
+
+	string_t p ;
+
+	if( zuluCryptTrueCryptOrVeraCryptVolume( mapper ) ){
+
+		p = _get_crypto_info_from_tcplay( mapper ) ;
 	}else{
-		q = _get_type_from_udev_1( mapper ) ;
-
-		StringAppendString( p,q ) ;
-
-		StringDelete( &q ) ;
+		p = _get_crypto_info_from_cryptsetup( mapper ) ;
 	}
 
-	_get_crypto_info( p,cd,mapper ) ;
+	if( p == StringVoid ){
 
-	if( StringPrefixEqual( device_name,"/dev/loop" ) ){
-
-		path = zuluCryptLoopDeviceAddress_1( device_name ) ;
+		return NULL ;
+	}else{
+		/*
+		 * zuluCryptGetMountPointFromPath() is defined in ./process_mountinfo.c
+		 */
+		path = zuluCryptGetMountPointFromPath( mapper ) ;
 
 		if( path != NULL ){
 
-			StringMultipleAppend( p,"\n device:   \t",device_name,"\n loop:   \t",path,NULL ) ;
+			zuluCryptFileSystemProperties( p,mapper,path ) ;
 			StringFree( path ) ;
-		}else{
-			StringMultipleAppend( p,"\n device:   \t",device_name,"\n loop:   \tNil",NULL ) ;
-		}
-	}else{
-		/*
-		 * zuluCryptResolvePath() is defined in resolve_path.c
-		 */
-		z = zuluCryptResolvePath( device_name ) ;
-		StringMultipleAppend( p,"\n device:   \t",z,"\n loop:   \tNil",NULL ) ;
-		StringFree( z ) ;
-	}
-
-	if( cad.flags == 1 ){
-
-		StringAppend( p,"\n mode:   \tread only" ) ;
-	}else{
-		StringAppend( p,"\n mode:   \tread and write" ) ;
-	}
-
-	k = crypt_keyslot_max( type ) ;
-
-	if( k > 0 ){
-
-		i = 0 ;
-
-		for( j = 0 ; j < k ; j++ ){
-
-			switch( crypt_keyslot_status( cd,j ) ){
-
-				case CRYPT_SLOT_ACTIVE_LAST : i++ ; break ;
-				case CRYPT_SLOT_ACTIVE      : i++ ; break ;
-				default : ;
-			}
 		}
 
-		StringMultipleAppend( p,"\n active slots:\t",StringIntToString_1( buffer,SIZE,i ),NULL ) ;
-
-		StringMultipleAppend( p," / ",StringIntToString_1( buffer,SIZE,k ),NULL ) ;
-	}else{
-		StringAppend( p,"\n active slots:\tNil" ) ;
+		return StringDeleteHandle( &p ) ;
 	}
-
-	/*
-	 * zuluCryptGetMountPointFromPath() is defined in ./process_mountinfo.c
-	 */
-	path = zuluCryptGetMountPointFromPath( mapper ) ;
-
-	if( path != NULL ){
-
-		zuluCryptFileSystemProperties( p,mapper,path ) ;
-		StringFree( path ) ;
-	}
-
-	return zuluExit( p,cd,device_name ) ;
-}
-
-/*
- * here,we are exploiting a simple observation that mapper will contain something like
- * "zuluCrypt-500-NAAN-sdc1-2091885911" and prepending "/dev/" infront of the 3rd component
- * will give us what we are looking for(/dev/sdc1). Hope this will always work.
- */
-static char * _get_device_name( const char * mapper )
-{
-	string_t st ;
-
-	char * e ;
-
-	stringList_t stl = StringListSplit( mapper,'-' ) ;
-
-	st = StringListStringAt( stl,3 ) ;
-
-	e = StringCopy_2( StringPrepend( st,"/dev/" ) ) ;
-
-	StringListDelete( &stl ) ;
-
-	return e ;
 }
 
 static char * _device_name( const char * mapper,char * ( *function )( const char * ) )
@@ -637,52 +631,23 @@ static char * _device_name( const char * mapper,char * ( *function )( const char
 
 	char * e = NULL ;
 
-	int64_t block_offset = 0 ;
-
-	char device[ PATH_MAX + 1 ] ;
+	char device[ PATH_MAX + 1 ] = { '\0' } ;
 
 	mapper = mapper + StringLastIndexOfChar_1( mapper,'/' ) + 1 ;
 
 	if( tc_api_initialize() ){
 
-		task = tc_api_task_init( "info_mapped" ) ;
-
-		if( tc_api_task_initialized( task ) ){
+		if( tc_api_task_initialize( &task,"info_mapped" ) ){
 
 			tc_api_task_set( task,"map_name",mapper ) ;
 
 			tc_api_task_do( task ) ;
 
-			tc_api_task_info_get( task,"block_offset",sizeof( block_offset ),&block_offset ) ;
 			tc_api_task_info_get( task,"device",sizeof( device ),device ) ;
 
 			tc_api_task_uninit( task ) ;
 
-			/*
-			 * 32256 is derived from 63(sectors) * 512(block size)
-			 */
-			if( block_offset == 32256 ){
-
-				/*
-				 * This is a hacky code path.
-				 *
-				 *  Given a device with a node address of something like "/dev/sdc1",
-				 *  the device will be reported as "/dev/sdc" if the device is a TrueCrypt
-				 *  system volume and this code path tries to figure out "/dev/sdc1" from "/dev/sdc".
-				 */
-
-				if( StringPrefixEqual( device,"/dev/sd" ) || StringPrefixEqual( device,"/dev/hd" ) ){
-
-					e = _get_device_name( mapper ) ;
-				}else{
-					/*
-					 * devices with no partitions do not seem to have the above problem
-					 */
-					e = function( device ) ;
-				}
-			}else{
-				e = function( device ) ;
-			}
+			e = function( device ) ;
 		}
 
 		tc_api_uninit() ;
