@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (c) 2012
+ *  Copyright (c) 2012-2015
  *  name : Francis Banyikwa
  *  email: mhogomchungu@gmail.com
  *  This program is free software: you can redistribute it and/or modify
@@ -36,6 +36,8 @@
 #include <sys/resource.h>
 #include <grp.h>
 
+#define _ignore_result( x ) if( x ){;}
+
 struct ProcessType_t{
 	pid_t pid ;
 	int fd_0[ 2 ] ; /* this variable is used to write to child process      */
@@ -351,11 +353,11 @@ pid_t ProcessStart( process_t p )
 			/*
 			 * drop privileges permanently
 			 */
-			seteuid( 0 ) ;
-			setgid( p->str.user_id ) ;
-			setgroups( 1,&p->str.user_id ) ;
-			setegid( p->str.user_id ) ;
-			setuid( p->str.user_id ) ;
+			_ignore_result( seteuid( 0 ) ) ;
+			_ignore_result( setgid( p->str.user_id ) ) ;
+			_ignore_result( setgroups( 1,&p->str.user_id ) ) ;
+			_ignore_result( setegid( p->str.user_id ) ) ;
+			_ignore_result( setuid( p->str.user_id ) ) ;
 		}
 
 		dup2( p->fd_0[ 0 ],0 ) ;
