@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (c) 2011
+ *  Copyright (c) 2011-2015
  *  name : Francis Banyikwa
  *  email: mhogomchungu@gmail.com
  *  This program is free software: you can redistribute it and/or modify
@@ -34,6 +34,8 @@
 #include <termios.h>
 #include <sys/mman.h>
 
+#define ignore_result( x ) if( x ){;}
+
 /*
  * a string memory block gows by below factor when it expands
  */
@@ -115,7 +117,7 @@ const char * StringToLowerCase( string_t st )
 static inline char * __StringExpandMemory( string_t st,size_t new_size )
 {
 	char * p ;
-	if( new_size >= st->length ) {
+	if( new_size >= st->length ){
 		st->length = new_size * FACTOR ;
 		p = realloc( st->string,st->length ) ;
 		if( p == NULL ){
@@ -344,7 +346,7 @@ string_t String( const char * cstring )
 			return _StringError() ;
 		}else{
 			memcpy( st->string,cstring,size + 1 ) ;
-			st->size = size  ;
+			st->size = size ;
 			st->length = size + 1 ;
 			st->owned = 0 ;
 			return st ;
@@ -580,7 +582,7 @@ const char * StringRemoveDigits( string_t st )
 {
 	char * e ;
 	char * f ;
-	int k ;
+	char k ;
 	size_t z ;
 
 	if( st == StringVoid ){
@@ -1072,14 +1074,19 @@ int StringStartsWithAtLeastOne( string_t st,... )
 	va_list list ;
 	va_start( list,st ) ;
 
-	while( 1 ){
-		entry = va_arg( list,const char * ) ;
-		if( entry == NULL ){
-			break ;
-		}else{
-			if( strncmp( st->string,entry,strlen( entry ) ) == 0 ){
-				r = 1 ;
+	if( st != StringVoid ){
+
+		while( 1 ){
+
+			entry = va_arg( list,const char * ) ;
+
+			if( entry == NULL ){
 				break ;
+			}else{
+				if( strncmp( st->string,entry,strlen( entry ) ) == 0 ){
+					r = 1 ;
+					break ;
+				}
 			}
 		}
 	}
@@ -1751,7 +1758,7 @@ string_t StringRandomString( size_t size )
 	}
 
 	while( g < size ){
-		read( f,&c,1 ) ;
+		ignore_result( read( f,&c,1 ) ) ;
 		if( c >= ' ' && c <= '~' ){
 			*( e + g ) = c ;
 			g++ ;
@@ -1985,11 +1992,11 @@ void StringWriteToFile( string_t st,const char * path,int mode )
 		return ;
 	}
 
-	write( fd,st->string,st->size ) ;
+	ignore_result( write( fd,st->string,st->size ) ) ;
 
 	close( fd ) ;
 
-	chown( path,getuid(),getgid() ) ;
+	ignore_result( chown( path,getuid(),getgid() ) ) ;
 	chmod( path,S_IRUSR | S_IWUSR | S_IRGRP | S_IROTH ) ;
 }
 
