@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (c) 2011
+ *  Copyright (c) 2011-2015
  *  name : Francis Banyikwa
  *  email: mhogomchungu@gmail.com
  *  This program is free software: you can redistribute it and/or modify
@@ -116,6 +116,16 @@ const char * StringAppendString( string_t st,string_t xt )  ;
  */
 int StringContains( string_t st,const char * str ) ;
 
+/*
+ * check if a string handled by st has str in it
+ * return 0 if str is found
+ * return 1 if str is not found
+ */
+static __inline__ int StringDoesNotContain( string_t st,const char * str )
+{
+	return !StringContains( st,str ) ;
+}
+
 /*
  * Append multiple string_t to a string handled by handle st .
  * Same requirement as StringMultipleAppend apply
