@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright ( c ) 2011
+ *  Copyright ( c ) 2011-2015
  *  name : Francis Banyikwa
  *  email: mhogomchungu@gmail.com
  *  This program is free software: you can redistribute it and/or modify
@@ -88,14 +88,11 @@ createvolume::createvolume( QWidget * parent ) :
 
 	m_veraCryptWarning.setWarningLabel( m_ui->veraCryptWarning ) ;
 
-	QStringList l ;
-
 	/*
 	 * for simplicity's sake,lets only show most popular file systems.
 	 */
-	l << "ext4" << "vfat" << "ntfs" << "ext2" << "ext3" ;
 
-	m_ui->comboBoxFS->addItems( l ) ;
+	m_ui->comboBoxFS->addItems( { "ext4","vfat","ntfs","ext2","ext3" } ) ;
 
 #if TRUECRYPT_CREATE
 	m_ui->comboBoxVolumeType->addItem( tr( "Normal TrueCrypt" ) ) ;
@@ -240,7 +237,7 @@ void createvolume::closeEvent( QCloseEvent * e )
 {
 	e->ignore() ;
 	if( m_isWindowClosable ){
-		pbCancelClicked() ;
+		this->pbCancelClicked() ;
 	}
 }
 
@@ -344,8 +341,11 @@ void createvolume::setOptions( int e )
 
 		auto _veraCryptVolume = [ this ](){
 
-			auto type = createvolume::createVolumeType( m_ui->comboBoxVolumeType->currentIndex() ) ;
-			return type == createvolume::normal_veracrypt || type == createvolume::normal_and_hidden_veracrypt ;
+			using cv = createvolume ;
+
+			auto e = cv::createVolumeType( m_ui->comboBoxVolumeType->currentIndex() ) ;
+
+			return e == cv::normal_veracrypt || e == cv::normal_and_hidden_veracrypt ;
 		} ;
 
 		auto _add_option = [ & ]( const QString& algo ){
