@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright ( c ) 2011
+ *  Copyright ( c ) 2011-2015
  *  name : Francis Banyikwa
  *  email: mhogomchungu@gmail.com
  *  This program is free software: you can redistribute it and/or modify
@@ -49,7 +49,7 @@ luksaddkey::luksaddkey( QWidget * parent ) :
 
 	m_isWindowClosable = true ;
 
-	m_ui->textEditPathToVolume->setText( QString( "" ) ) ;
+	m_ui->textEditPathToVolume->setText( QString() ) ;
 
 	m_ui->textEditExistingPassphrase->setEchoMode( QLineEdit::Password ) ;
 	m_ui->textEditPassphraseToAdd->setEchoMode( QLineEdit::Password ) ;
