@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright ( c ) 2011
+ *  Copyright ( c ) 2011-2015
  *  name : Francis Banyikwa
  *  email: mhogomchungu@gmail.com
  *  This program is free software: you can redistribute it and/or modify
@@ -32,6 +32,7 @@
 #include <QEventLoop>
 #include <QTimer>
 #include <QMenu>
+#include <QVector>
 
 #include <functional>
 #include <utility>
@@ -47,6 +48,9 @@
 #include <QObject>
 #include <QLabel>
 
+#include <poll.h>
+#include <fcntl.h>
+
 class QByteArray ;
 class QEvent ;
 
@@ -69,7 +73,7 @@ namespace utility
 
 		if( uid != -1 && fd != -1 ){
 
-			fchown( fd,uid,uid ) ;
+			if( fchown( fd,uid,uid ) ){;}
 		}
 	}
 
@@ -79,13 +83,32 @@ namespace utility
 
 		if( uid != -1 ){
 
-			chown( path,uid,uid ) ;
+			if( chown( path,uid,uid ) ){;}
 		}
 	}
+
+	template< typename T >
+	void changeFilePermissions( const T& f,int mode = 0777 )
+	{
+		if( fchmod( f.handle(),mode ) ){;}
+	}
 }
 
 namespace utility
 {
+	class Array
+	{
+	public:
+		explicit Array( const QString&,char splitter = '\n' ) ;
+		explicit Array( const QStringList& ) ;
+		size_t size() ;
+		char * const * value() ;
+	private :
+		void setUp() ;
+		QVector< const char * > m_vector ;
+		QList< QByteArray > m_list ;
+	};
+
 	struct wallet
 	{
 		bool opened ;
@@ -94,17 +117,15 @@ namespace utility
 		QString password ;
 	};
 
-	template< typename T > void debug( T t )
-	{
-		qDebug() << t ;
-	}
-
 	int startApplication( const char * appName,std::function<int()> ) ;
 
 	wallet getKeyFromWallet( LxQt::Wallet::walletBackEnd,const QString& keyID,const QString& pwd = QString() ) ;
 
 	QString cmdArgumentValue( const QStringList&,const QString& arg,const QString& defaulT = QString() ) ;
 
+	bool userBelongsToGroup( const char * groupname ) ;
+	bool runningInMixedMode( void ) ;
+	bool notRunningInMixedMode( void ) ;
 	void addToFavorite( const QString& dev,const QString& m_point ) ;
 	QStringList readFavorites( void ) ;
 	void removeFavoriteEntry( const QString& ) ;
@@ -142,8 +163,16 @@ namespace utility
 	bool userHasGoodVersionOfWhirlpool( void ) ;
 	void licenseInfo( QWidget * ) ;
 
+	bool ProcessExecute( const QString& m_point,const QString& exe,const QString& env,int uid ) ;
+
+	QVector<int> getWindowDimensions( const QString& application ) ;
+	void setWindowDimensions( const QVector<int>&,const QString& application ) ;
+
 	void createPlugInMenu( QMenu *,const QString&,const QString&,const QString&,bool ) ;
 
+	QFont getFont( QWidget * ) ;
+	void saveFont( const QFont& ) ;
+
 	::Task::future< int >& clearVolume( const QString& volumePath,bool * exit,std::function< void( int ) > ) ;
 	::Task::future< int >& exec( const QString& ) ;
 	::Task::future< QStringList >& luksEmptySlots( const QString& volumePath ) ;
@@ -184,13 +213,17 @@ namespace utility
 		{
 			return m_fd ;
 		}
+		bool opened() const
+		{
+			return m_fd != -1 ;
+		}
 		char getChar() const
 		{
 			char z ;
 
 			while( true ){
 
-				::read( m_fd,&z,1 ) ;
+				while( ::read( m_fd,&z,1 ) != 1 ){;}
 
 				if( z > ' ' && z < '~' ){
 
@@ -206,7 +239,7 @@ namespace utility
 		}
 		void writeChar( char r ) const
 		{
-			::write( m_fd,&r,1 ) ;
+			if( ::write( m_fd,&r,1 ) ){;}
 		}
 		~fileHandle()
 		{
@@ -224,6 +257,32 @@ namespace utility
 	} ;
 }
 
+namespace utility
+{
+	class monitor_mountinfo
+	{
+	public:
+		monitor_mountinfo()
+		{
+			m_handle.open( "/proc/self/mountinfo" ) ;
+			m_monitor.fd     = m_handle.handle() ;
+			m_monitor.events = POLLPRI ;
+		}
+		operator bool()
+		{
+			return m_handle.opened() ;
+		}
+		bool gotEvent() const
+		{
+			poll( &m_monitor,1,-1 ) ;
+			return true ;
+		}
+	private:
+		utility::fileHandle m_handle ;
+		mutable struct pollfd m_monitor ;
+	};
+}
+
 namespace utility
 {
 	class Task
