@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright ( c ) 2011
+ *  Copyright ( c ) 2011-2015
  *  name : Francis Banyikwa
  *  email: mhogomchungu@gmail.com
  *  This program is free software: you can redistribute it and/or modify
@@ -61,7 +61,6 @@
 #include "cryptfiles.h"
 #include "dialogmsg.h"
 #include "managesystemvolumes.h"
-#include "userfont.h"
 #include "walletconfig.h"
 #include "tablewidget.h"
 #include "utility.h"
@@ -71,10 +70,12 @@
 #include "veracrypt_support.h"
 #include "pdf_path.h"
 
+#include "checkforupdates.h"
+
+#include <memory>
+
 zuluCrypt::zuluCrypt( QWidget * parent ) :QMainWindow( parent ),m_trayIcon( 0 )
 {
-	this->setLocalizationLanguage() ;
-	m_ui = new Ui::zuluCrypt ;
 }
 
 void zuluCrypt::setLocalizationLanguage()
@@ -97,6 +98,9 @@ void zuluCrypt::setLocalizationLanguage()
 
 void zuluCrypt::setUpApp( const QString& volume )
 {
+	this->setLocalizationLanguage() ;
+	m_ui = new Ui::zuluCrypt ;
+
 	this->setupUIElements() ;
 	this->setupConnections() ;
 	this->initFont() ;
@@ -104,6 +108,7 @@ void zuluCrypt::setUpApp( const QString& volume )
 	this->initTray() ;
 	this->updateVolumeList( volume ) ;
 	this->info() ;
+	this->autoUpdateCheck() ;
 }
 
 void zuluCrypt::updateVolumeList( const QString& volume )
@@ -185,8 +190,7 @@ void zuluCrypt::initKeyCombo()
 
 void zuluCrypt::initFont()
 {
-	userfont f( this ) ;
-	setUserFont( f.getFont() ) ;
+	this->setUserFont( utility::getFont( this ) ) ;
 }
 
 void zuluCrypt::raiseWindow()
@@ -221,26 +225,24 @@ void zuluCrypt::start()
 	 * runs.
 	 */
 
-	QStringList l = QCoreApplication::arguments() ;
+	QStringList l  = QCoreApplication::arguments() ;
 
 	QString e      = utility::cmdArgumentValue( l,"-d" ) ;
+
 	m_openPath     = utility::cmdArgumentValue( l,"-m","xdg-open" ) ;
 	m_startHidden  = l.contains( "-e" ) ;
 
-	if( utility::userIsRoot() ){
+	m_env          = utility::cmdArgumentValue( l,"-z","" ) ;
 
-		utility::setUID( utility::cmdArgumentValue( l,"-K","-1" ).toInt() ) ;
-	}
+	utility::setUID( utility::cmdArgumentValue( l,"-K","-1" ).toInt() ) ;
 
-	auto instance = new oneinstance( this,"zuluCrypt-gui.socket","raiseWindow",e ) ;
+	new oneinstance( this,"zuluCrypt-gui.socket","raiseWindow",e,[ this,e ]( QObject * instance ){
 
-	if( instance->onlyInstance() ){
+		this->setUpApp( e ) ;
 
 		connect( instance,SIGNAL( raise() ),this,SLOT( raiseWindow() ) ) ;
 		connect( instance,SIGNAL( raiseWithDevice( QString ) ),this,SLOT( raiseWindow( QString ) ) ) ;
-
-		this->setUpApp( e ) ;
-	}
+	} ) ;
 }
 
 void zuluCrypt::initTray()
@@ -276,7 +278,6 @@ void zuluCrypt::setupUIElements()
 {
 	m_ui->setupUi( this ) ;
 
-	this->setFixedSize( this->size() ) ;
 	this->setWindowIcon( QIcon( ":/zuluCrypt.png" ) ) ;
 
 	m_trayIcon = new QSystemTrayIcon( this ) ;
@@ -284,14 +285,21 @@ void zuluCrypt::setupUIElements()
 
 	QMenu * trayMenu = new QMenu( this ) ;
 
-	trayMenu->addAction( tr( "Show The Interface" ),this,SLOT( raiseWindow() ) ) ;
 	trayMenu->addAction( tr( "Quit" ),this,SLOT( closeApplication() ) ) ;
 
 	m_trayIcon->setContextMenu( trayMenu ) ;
 
-	m_ui->tableWidget->setColumnWidth( 0,298 ) ;
-	m_ui->tableWidget->setColumnWidth( 1,336 ) ;
-	//m_ui->tableWidget->setColumnWidth( 2,70 ) ;
+	QVector<int> f = utility::getWindowDimensions( "zuluCrypt" ) ;
+
+	int * e = f.data() ;
+
+	this->window()->setGeometry( *( e + 0 ),*( e + 1 ),*( e + 2 ),*( e + 3 ) ) ;
+
+	QTableWidget * table = m_ui->tableWidget ;
+
+	table->setColumnWidth( 0,*( e + 4 ) ) ;
+	table->setColumnWidth( 1,*( e + 5 ) ) ;
+	table->setColumnWidth( 2,*( e + 6 ) ) ;
 }
 
 void zuluCrypt::itemEntered( QTableWidgetItem * item )
@@ -346,6 +354,7 @@ void zuluCrypt::setupConnections()
 	connect( m_ui->actionManage_volumes_in_gnome_wallet,SIGNAL( triggered() ),this,SLOT( manageVolumesInGNOMEWallet() ) ) ;
 	connect( m_ui->actionManage_volumes_in_internal_wallet,SIGNAL( triggered() ),this,SLOT( manageVolumesInInternalWallet() ) ) ;
 	connect( m_ui->actionOpen_zuluCrypt_pdf,SIGNAL( triggered() ),this,SLOT( openpdf() ) ) ;
+	connect( m_ui->actionCheck_For_Update,SIGNAL( triggered() ),this,SLOT( updateCheck() ) ) ;
 
 	connect( this,SIGNAL( closeVolume( QTableWidgetItem *,int ) ),this,SLOT( closeAll( QTableWidgetItem *,int ) ) ) ;
 
@@ -355,8 +364,14 @@ void zuluCrypt::setupConnections()
 	connect( m_ui->actionBackup_header,SIGNAL( triggered() ),this,SLOT( volumeHeaderBackUp() ) ) ;
 	connect( m_ui->actionRestore_header,SIGNAL( triggered() ),this,SLOT( volumeRestoreHeader() ) ) ;
 
-	m_ui->actionManage_volumes_in_gnome_wallet->setEnabled( LxQt::Wallet::backEndIsSupported( LxQt::Wallet::secretServiceBackEnd ) ) ;
-	m_ui->actionManage_volumes_in_kde_wallet->setEnabled( LxQt::Wallet::backEndIsSupported( LxQt::Wallet::kwalletBackEnd ) ) ;
+	if( utility::runningInMixedMode() ){
+
+		m_ui->actionManage_volumes_in_gnome_wallet->setEnabled( false ) ;
+		m_ui->actionManage_volumes_in_kde_wallet->setEnabled( false ) ;
+	}else{
+		m_ui->actionManage_volumes_in_gnome_wallet->setEnabled( LxQt::Wallet::backEndIsSupported( LxQt::Wallet::secretServiceBackEnd ) ) ;
+		m_ui->actionManage_volumes_in_kde_wallet->setEnabled( LxQt::Wallet::backEndIsSupported( LxQt::Wallet::kwalletBackEnd ) ) ;
+	}
 
 	connect( m_ui->menuOptions,SIGNAL( aboutToShow() ),this,SLOT( optionMenuAboutToShow() ) ) ;
 
@@ -393,6 +408,16 @@ void zuluCrypt::openpdf()
 	}
 }
 
+void zuluCrypt::updateCheck()
+{
+	checkForUpdates::checkForUpdate( this ) ;
+}
+
+void zuluCrypt::autoUpdateCheck()
+{
+	checkForUpdates::autoCheckForUpdate( this,"zuluCrypt" ) ;
+}
+
 void zuluCrypt::info()
 {
 	QString e = QDir::homePath() + "/.zuluCrypt/doNotshowWarning.option" ;
@@ -654,8 +679,8 @@ void zuluCrypt::fonts()
 		}
 
 		this->setUserFont( Font ) ;
-		userfont f( this ) ;
-		f.saveFont( Font ) ;
+		
+		utility::saveFont( Font ) ;
 	}
 }
 
@@ -700,6 +725,7 @@ void zuluCrypt::setUserFont( QFont Font )
 	m_ui->actionVeracrypt_container_in_a_file->setFont( Font ) ;
 	m_ui->actionVeracrypt_container_in_a_partition->setFont( Font ) ;
 	m_ui->actionOpen_zuluCrypt_pdf->setFont( Font ) ;
+	m_ui->actionCheck_For_Update->setFont( Font ) ;
 }
 
 void zuluCrypt::createEncryptedpartitionUI()
@@ -776,7 +802,9 @@ void zuluCrypt::favAboutToHide()
 
 void zuluCrypt::favClicked( QAction * e )
 {
-	QStringList l = e->text().split( "\t" ) ;
+	auto r = e->text() ;
+	r.remove( "&" ) ;
+	auto l = r.split( "\t" ) ;
 	emit favClickedVolume( l.at( 0 ),l.at( 1 ) ) ;
 }
 
@@ -820,7 +848,7 @@ void zuluCrypt::openFolder()
 
 void zuluCrypt::openFolder( QString path )
 {
-	utility::openMountPoint( path,m_openPath ).then( [ this ]( bool failed ){
+	utility::openMountPoint( path,m_openPath,m_env ).then( [ this ]( bool failed ){
 
 		if( failed ){
 
@@ -865,9 +893,12 @@ void zuluCrypt::itemClicked( QTableWidgetItem * item,bool clicked )
 
 	QFile f( QDir::homePath() + "/.zuluCrypt/favorites" ) ;
 
-	f.open( QIODevice::ReadOnly ) ;
+	QByteArray data ;
 
-	QByteArray data = f.readAll() ;
+	if( f.open( QIODevice::ReadOnly ) ){
+
+		data = f.readAll() ;
+	}
 
 	QAction * ac = m.addAction( tr( "Add To Favorite" ) ) ;
 
@@ -1158,6 +1189,22 @@ void zuluCrypt::decryptFile( const QString& e )
 
 zuluCrypt::~zuluCrypt()
 {
+	QVector<int> e ;
+
+	auto q = m_ui->tableWidget ;
+
+	const QRect& r = this->window()->geometry() ;
+
+	e << r.x()
+	  << r.y()
+	  << r.width()
+	  << r.height()
+	  << q->columnWidth( 0 )
+	  << q->columnWidth( 1 )
+	  << q->columnWidth( 2 ) ;
+
+	utility::setWindowDimensions( e,"zuluCrypt" ) ;
+
 	delete m_ui ;
 	delete m_trayIcon ;
 }
