@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright ( c ) 2011
+ *  Copyright ( c ) 2011-2015
  *  name : Francis Banyikwa
  *  email: mhogomchungu@gmail.com
  *  This program is free software: you can redistribute it and/or modify
@@ -39,6 +39,7 @@ class luksaddkey ;
 class managevolumeheader ;
 class cryptfiles ;
 class walletconfig ;
+class QNetworkReply ;
 
 namespace LxQt{
 namespace Wallet{
@@ -140,7 +141,9 @@ private slots :
 	void walletIsOpen( bool ) ;
 	void optionMenuAboutToShow( void ) ;
 	void openpdf( void ) ;
+	void updateCheck( void ) ;
 private:
+	void autoUpdateCheck( void ) ;
 	void updateVolumeList( const QString& volume = QString() ) ;
 	void dragEnterEvent( QDragEnterEvent * ) ;
 	void dropEvent( QDropEvent * ) ;
@@ -165,12 +168,13 @@ private:
 	void closeStatusErrorMessage( int ) ;
 	void setUpApp( const QString& ) ;
 	void decryptFile( const QString& ) ;
-	Ui::zuluCrypt * m_ui ;
-	QSystemTrayIcon * m_trayIcon ;
+	Ui::zuluCrypt * m_ui = nullptr ;
+	QSystemTrayIcon * m_trayIcon = nullptr ;
 	QString m_openPath ;
 	bool m_startHidden ;
-	LxQt::Wallet::Wallet * m_wallet ;
+	LxQt::Wallet::Wallet * m_wallet = nullptr ;
 	int m_userID ;
+	QString m_env ;
 };
 
 #endif // ZULUCRYPT_H
