@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (c) 2012
+ *  Copyright (c) 2012-2015
  *  name : Francis Banyikwa
  *  email: mhogomchungu@gmail.com
  *  This program is free software: you can redistribute it and/or modify
@@ -32,6 +32,16 @@
 #include <unistd.h>
 #include <grp.h>
 
+static void _seteuid( uid_t uid )
+{
+	if( seteuid( uid ) ){;}
+}
+
+static void _setuid( uid_t uid )
+{
+	if( setuid( uid ) ){;}
+}
+
 /*
  * All functions with "EXE" in their names are defined somewhere in ../zuluCrypt-cli/bin
  */
@@ -161,34 +171,23 @@ static int _zuluMountMountedList( uid_t uid )
 
 static int _zuluPartitionHasCryptoFs( const char * device )
 {
-	int st ;
-	string_t fs = StringVoid ;
+	int r ;
 	/*
-	* zuluCryptSecurityGainElevatedPrivileges() is defined in ../zuluCrypt-cli/bin/security.c
-	*/
-	zuluCryptSecurityGainElevatedPrivileges() ;
-	/*
-	 * zuluCryptGetFileSystemFromDevice() is defined in ../zuluCrypt-cli/lib/blkid_evaluate_tag.c
+	 * zuluCryptSecurityGainElevatedPrivileges() is defined in ../zuluCrypt-cli/bin/security.c
 	 */
-	fs = zuluCryptGetFileSystemFromDevice( device ) ;
+	zuluCryptSecurityGainElevatedPrivileges() ;
+
+	/*
+	 * zuluCryptDeviceHasEncryptedFileSystem() is defined in ../zuluCrypt-cli/lib/blkid_evaluate_tag.c
+	 */
+	r = zuluCryptDeviceHasEncryptedFileSystem( device ) ;
+
 	/*
 	 * zuluCryptSecurityDropElevatedPrivileges() is defined in ../zuluCrypt-cli/bin/security.c
 	 */
 	zuluCryptSecurityDropElevatedPrivileges() ;
-	if( fs == StringVoid ){
-		/*
-		 * no file system is found,assuming it is a non LUKS encrypted volume
-		 */
-		return 1 ;
-	}else{
-		/*
-		 * st == 1 means the volume is cryto_LUKS
-		 * st == 0 means the volume has a regular file system
-		 */
-		st = StringEqual( fs,"crypto_LUKS" ) ;
-		StringDelete( &fs ) ;
-		return st ;
-	}
+
+	return r ;
 }
 
 static int _zuluMountPrintVolumeDeviceName( const char * device )
@@ -554,7 +553,7 @@ int main( int argc,char * argv[] )
 	/*
 	 * setgroups() requires seteuid(0) ;
 	 */
-	seteuid( 0 ) ;
+	_seteuid( 0 ) ;
 	if( setgroups( 1,&gid ) != 0 ){
 		_privilegeEvelationError( gettext( "ERROR: setgroups() failed" ) ) ;
 	}
@@ -578,8 +577,8 @@ int main( int argc,char * argv[] )
 	 * Run with higher priority to speed things up
 	 */
 	setpriority( PRIO_PROCESS,0,-15 ) ;
-	setuid( 0 ) ;
-	seteuid( uid ) ;
+	_setuid( 0 ) ;
+	_seteuid( uid ) ;
 
 	/*
 	 * zuluCryptClearDeadMappers() is defined in ../zuluCrypt-cli/bin/clear_dead_mapper.c
@@ -628,6 +627,13 @@ int main( int argc,char * argv[] )
 		args.key = StringContent( *k ) ;
 	}
 
+	if( args.type != NULL ){
+		k = StringListAssign( stl ) ;
+		*k = String( args.type ) ;
+		_hide( args.type ) ;
+		args.type = StringContent( *k ) ;
+	}
+
 	for( i = 0 ; args.tcrypt_multiple_keyfiles[ i ] != NULL ; i++ ){
 
 		k = StringListAssign( stl ) ;
