@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (c) 2012
+ *  Copyright (c) 2012-2015
  *  name : Francis Banyikwa
  *  email: mhogomchungu@gmail.com
  *  This program is free software: you can redistribute it and/or modify
@@ -43,6 +43,7 @@
 #include "zulumounttask.h"
 #include "veracrypt_support.h"
 #include "truecrypt_support.h"
+#include "veracryptpimdialog.h"
 
 #define KWALLET         "kde wallet"
 #define INTERNAL_WALLET "internal wallet"
@@ -124,6 +125,7 @@ keyDialog::keyDialog( QWidget * parent,QTableWidget * table,const volumeEntryPro
 	_add_action( tr( "Set File System Options" ) ) ;
 	_add_action( tr( "Set Volume Offset" ) ) ;
 	_add_action( tr( "Set Volume As VeraCrypt Volume" ) ) ;
+	_add_action( tr( "Set VeraCrypt PIM value" ) ) ;
 
 	m_ui->cbKeyType->addItem( tr( "Key" ) ) ;
 	m_ui->cbKeyType->addItem( tr( "Keyfile" ) ) ;
@@ -210,15 +212,30 @@ void keyDialog::doAction( QAction * ac )
 {
 	QString e = ac->text() ;
 
-	if( e == tr( "Set File System 0ptions" ) ){
+	e.remove( "&" ) ;
+
+	if( e == tr( "Set File System Options" ) ){
 		this->showFileSystemOptionWindow() ;
 	}else if( e == tr( "Set Volume Offset" ) ){
 		this->showOffSetWindowOption() ;
 	}else if( e == tr( "Set Volume As VeraCrypt Volume" ) ){
 		m_veraCryptVolume = true ;
+	}else if( e == tr( "Set VeraCrypt PIM value" ) ){
+
+		auto v = new VeraCryptPIMDialog( this ) ;
+
+		connect( v,SIGNAL( setValue( int ) ),this,SLOT( setVeraCryptPIMValue( int ) ) ) ;
+
+		v->Show() ;
 	}
 }
 
+void keyDialog::setVeraCryptPIMValue( int e )
+{
+	m_veraCryptPIMValue = e ;
+	m_veraCryptVolume = e > 0 ;
+}
+
 void keyDialog::deviceOffSet( QString deviceOffSet,QString key )
 {
 	m_deviceOffSet = QString( " -o %1" ).arg( deviceOffSet ) ;
@@ -323,7 +340,11 @@ void keyDialog::Plugin()
 
 void keyDialog::pbPluginEntryClicked( QAction * e )
 {
-	if( e->text() != tr( "Cancel" ) ){
+	auto r = e->text() ;
+
+	r.remove( "&" ) ;
+
+	if( r != tr( "Cancel" ) ){
 
 		m_ui->lineEditKey->setText( e->text() ) ;
 	}
@@ -393,12 +414,22 @@ void keyDialog::pbOpen()
 
 void keyDialog::encfsMount()
 {
-	QString m = utility::mountPath( m_point ) ;
+	auto m = utility::mountPath( utility::mountPathPostFix( m_ui->lineEditMountPoint->text() ) ) ;
 
 	bool ro = m_ui->checkBoxOpenReadOnly->isChecked() ;
 
 	if( zuluMountTask::encfsMount( m_path,m,m_key,ro ).await() ){
 
+		/*
+		 * TODO: Not suspending for a while causes a process that open the mount point
+		 * to exit prematurely with "QProcess: Destroyed while process is still running." warning.
+		 * look into why this happens.
+		 *
+		 */
+		this->hide() ;
+
+		utility::Task::suspend( 2 ) ;
+
 		emit openMountPoint( m ) ;
 
 		this->HideUI() ;
@@ -547,7 +578,12 @@ void keyDialog::openVolume()
 
 	if( m_veraCryptVolume ){
 
-		exe += " -t vera " + m ;
+		if( m_veraCryptPIMValue > 0 ){
+
+			exe += " -t veracrypt." + QString::number( m_veraCryptPIMValue ) + " " + m ;
+		}else{
+			exe += " -t veracrypt " + m ;
+		}
 	}else{
 		exe += " " + m ;
 	}
@@ -568,7 +604,7 @@ void keyDialog::openVolume()
 			/*
 			 * The volume is reported as opened and it actually is
 			 */
-			emit openMountPoint( utility::mountPath( m_point ) ) ;
+			emit openMountPoint( utility::mountPath( mountPoint ) ) ;
 		}else{
 			/*
 			 * The volume is reported as opened but it isnt,possible reason is a backe end crash
