@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (c) 2012
+ *  Copyright (c) 2012-2015
  *  name : Francis Banyikwa
  *  email: mhogomchungu@gmail.com
  *  This program is free software: you can redistribute it and/or modify
@@ -41,11 +41,11 @@
 #include <QFile>
 
 #include <utility>
+#include <initializer_list>
 
 #include <unistd.h>
 #include "keydialog.h"
 #include "../zuluCrypt-gui/dialogmsg.h"
-#include "../zuluCrypt-gui/userfont.h"
 #include "../zuluCrypt-gui/tablewidget.h"
 #include "mountpartition.h"
 #include "oneinstance.h"
@@ -54,23 +54,9 @@
 #include "../zuluCrypt-gui/utility.h"
 #include "zulumounttask.h"
 #include "../zuluCrypt-gui/task.h"
+#include "../zuluCrypt-gui/checkforupdates.h"
 
-template< typename T >
-class Object_raii
-{
-public:
-	explicit Object_raii( T t ) : m_Object( t )
-	{
-	}
-	~Object_raii()
-	{
-		delete m_Object ;
-	}
-private:
-	T m_Object ;
-};
-
-#define Object_raii( x ) Object_raii< decltype( x ) > Object_raii_x( x ) ; Q_UNUSED( Object_raii_x )
+#include <memory>
 
 MainWindow::MainWindow( QWidget * parent ) : QWidget( parent )
 {
@@ -82,13 +68,25 @@ void MainWindow::setUpApp( const QString& volume )
 	m_ui = new Ui::MainWindow ;
 	m_ui->setupUi( this ) ;
 
-	this->setFixedSize( this->size() ) ;
+	m_ui->pbunlockencfs->setMinimumHeight( 31 ) ;
+	m_ui->pbmenu->setMinimumHeight( 31 ) ;
+	m_ui->pbmount->setMinimumHeight( 31 ) ;
+	m_ui->pbupdate->setMinimumHeight( 31 ) ;
+
+	QVector<int> f = utility::getWindowDimensions( "zuluMount" ) ;
+
+	int * e = f.data() ;
+
+	this->window()->setGeometry( *( e + 0 ),*( e + 1 ),*( e + 2 ),*( e + 3 ) ) ;
+
+	QTableWidget * table = m_ui->tableWidget ;
+
+	table->setColumnWidth( 0,*( e + 4 ) ) ;
+	table->setColumnWidth( 1,*( e + 5 ) ) ;
+	table->setColumnWidth( 2,*( e + 6 ) ) ;
+	table->setColumnWidth( 4,*( e + 7 ) ) ;
+	table->setColumnWidth( 5,*( e + 8 ) ) ;
 
-	m_ui->tableWidget->setColumnWidth( 0,220 ) ;
-	m_ui->tableWidget->setColumnWidth( 1,320 ) ;
-	m_ui->tableWidget->setColumnWidth( 2,145 ) ;
-	m_ui->tableWidget->setColumnWidth( 4,87 ) ;
-	m_ui->tableWidget->setColumnWidth( 5,87 ) ;
 	m_ui->tableWidget->hideColumn( 3 ) ;
 
 #if QT_VERSION < QT_VERSION_CHECK( 5,0,0 )
@@ -108,7 +106,7 @@ void MainWindow::setUpApp( const QString& volume )
 		 this,SLOT( slotCurrentItemChanged( QTableWidgetItem *,QTableWidgetItem * ) ) ) ;
 	connect( m_ui->pbmount,SIGNAL( clicked() ),this,SLOT( pbMount() ) ) ;
 	connect( m_ui->pbupdate,SIGNAL( clicked()),this,SLOT( pbUpdate() ) ) ;
-	connect( m_ui->pbclose,SIGNAL( clicked() ),this,SLOT( pbClose() ) ) ;
+	connect( m_ui->pbmenu,SIGNAL( clicked() ),this,SLOT( pbMenu() ) ) ;
 	connect( m_ui->tableWidget,SIGNAL( itemClicked( QTableWidgetItem * ) ),this,SLOT( itemClicked( QTableWidgetItem * ) ) ) ;
 	connect( m_ui->pbunlockencfs,SIGNAL( clicked() ),this,SLOT( unlockencfs() ) ) ;
 
@@ -144,12 +142,6 @@ void MainWindow::setUpApp( const QString& volume )
 	trayMenu->addAction( autoOpenFolderOnMount ) ;
 
 	auto ac = new QAction( this ) ;
-	ac->setText( tr( "Show The Interface" ) ) ;
-	connect( ac,SIGNAL( triggered() ),this,SLOT( raiseWindow() ) ) ;
-
-	trayMenu->addAction( ac ) ;
-
-	ac = new QAction( this ) ;
 	ac->setText( tr( "Unmount All" ) ) ;
 	connect( ac,SIGNAL( triggered() ),this,SLOT( unMountAll() ) ) ;
 
@@ -167,17 +159,24 @@ void MainWindow::setUpApp( const QString& volume )
 	connect( m_hidden_volume_menu,SIGNAL( triggered( QAction * ) ),this,SLOT( removeVolumeFromHiddenVolumeList( QAction * ) ) ) ;
 	connect( m_hidden_volume_menu,SIGNAL( aboutToShow() ),this,SLOT( showHiddenVolumeList() ) ) ;
 
+	ac = new QAction( this ) ;
+	ac->setText( tr( "Check For Update" ) ) ;
+	connect( ac,SIGNAL( triggered() ),this,SLOT( updateCheck() ) ) ;
+	trayMenu->addAction( ac ) ;
+
 	ac = new QAction( this ) ;
 	ac->setText( tr( "About" ) ) ;
 	connect( ac,SIGNAL( triggered() ),this,SLOT( licenseInfo() ) ) ;
 	trayMenu->addAction( ac ) ;
 
-	trayMenu->addAction( tr( "Quit" ),this,SLOT( pbClose() ) ) ;
+	trayMenu->addAction( tr( "Quit" ),this,SLOT( closeApplication() ) ) ;
 	m_trayIcon->setContextMenu( trayMenu ) ;
 
 	connect( m_trayIcon,SIGNAL( activated( QSystemTrayIcon::ActivationReason ) ),
 		 this,SLOT( slotTrayClicked( QSystemTrayIcon::ActivationReason ) ) ) ;
 
+	m_ui->pbmenu->setMenu( m_trayIcon->contextMenu() ) ;
+
 	m_trayIcon->show() ;
 
 	QString dirPath = utility::homePath() + "/.zuluCrypt/" ;
@@ -198,6 +197,8 @@ void MainWindow::setUpApp( const QString& volume )
 	}else{
 		this->showMoungDialog( volume ) ;
 	}
+
+	this->autoUpdateCheck() ;
 }
 
 void MainWindow::licenseInfo()
@@ -205,6 +206,16 @@ void MainWindow::licenseInfo()
 	utility::licenseInfo( this ) ;
 }
 
+void MainWindow::updateCheck()
+{
+	checkForUpdates::checkForUpdate( this ) ;
+}
+
+void MainWindow::autoUpdateCheck()
+{
+	checkForUpdates::autoCheckForUpdate( this,"zuluMount" ) ;
+}
+
 void MainWindow::removeVolumeFromHiddenVolumeList( QAction * ac )
 {
 	this->disableAll() ;
@@ -276,7 +287,9 @@ void MainWindow::removeVolumeFromVisibleVolumeList( QAction * ac )
 
 void MainWindow::favoriteClicked( QAction * ac )
 {
-	this->showMoungDialog( ac->text() ) ;
+	auto e = ac->text() ;
+	e.remove( "&" ) ;
+	this->showMoungDialog( e ) ;
 }
 
 void MainWindow::showFavorites()
@@ -356,10 +369,15 @@ void MainWindow::startAutoMonitor()
 	m_events->start() ;
 }
 
+void MainWindow::closeApplication()
+{
+	m_events->stop() ;
+}
+
 /*
  * This should be the only function that closes the application
  */
-void MainWindow::pbClose()
+void MainWindow::pbMenu()
 {
 	m_events->stop() ;
 }
@@ -369,9 +387,9 @@ void MainWindow::quitApplication()
 	QCoreApplication::quit() ;
 }
 
-void MainWindow::autoMountVolume( volumeEntryProperties * entry )
+void MainWindow::autoMountVolume( volumeEntryProperties * e )
 {
-	Object_raii( entry ) ;
+	std::unique_ptr< volumeEntryProperties > entry( e ) ;
 
 	if( entry && entry->entryisValid() ){
 
@@ -496,23 +514,19 @@ void MainWindow::Show()
 
 	m_startHidden  = l.contains( "-e" ) ;
 	m_folderOpener = utility::cmdArgumentValue( l,"-m","xdg-open" ) ;
+	m_env          = utility::cmdArgumentValue( l,"-z","" ) ;
 
-	if( utility::userIsRoot() ){
-
-		utility::setUID( utility::cmdArgumentValue( l,"-K","-1" ).toInt() ) ;
-	}
+	utility::setUID( utility::cmdArgumentValue( l,"-K","-1" ).toInt() ) ;
 
 	QString volume = utility::cmdArgumentValue( l,"-d" ) ;
 
-	auto instance = new oneinstance( this,"zuluMount-gui.socket","startGUI",volume ) ;
-
-	if( instance->onlyInstance() ){
+	new oneinstance( this,"zuluMount-gui.socket","startGUI",volume,[ this,volume ]( QObject * instance ){
 
 		connect( instance,SIGNAL( raise() ),this,SLOT( raiseWindow() ) ) ;
 		connect( instance,SIGNAL( raiseWithDevice( QString ) ),this,SLOT( raiseWindow( QString ) ) ) ;
 
 		this->setUpApp( volume ) ;
-	}
+	} ) ;
 }
 
 void MainWindow::showContextMenu( QTableWidgetItem * item,bool itemClicked )
@@ -712,14 +726,13 @@ void MainWindow::setUpShortCuts()
 	QList<QKeySequence> e ;
 	e.append( Qt::Key_C ) ;
 	qa->setShortcuts( e ) ;
-	connect( qa,SIGNAL( triggered() ),this,SLOT( pbClose() ) ) ;
+	connect( qa,SIGNAL( triggered() ),this,SLOT( closeApplication() ) ) ;
 	this->addAction( qa ) ;
 }
 
 void MainWindow::setUpFont()
 {
-	userfont F( this ) ;
-	this->setFont( F.getFont() ) ;
+	this->setFont( utility::getFont( this ) ) ;
 }
 
 void MainWindow::closeEvent( QCloseEvent * e )
@@ -788,9 +801,7 @@ void MainWindow::slotMount()
 	auto table = m_ui->tableWidget ;
 	int row = table->currentRow() ;
 
-	volumeEntryProperties entry( tablewidget::tableRowEntries( table,row ) ) ;
-
-	this->mount( entry ) ;
+	this->mount( volumeEntryProperties( tablewidget::tableRowEntries( table,row ) ) ) ;
 }
 
 void MainWindow::showMoungDialog( const volumeEntryProperties& v )
@@ -816,11 +827,7 @@ void MainWindow::showMoungDialog( const QString& volume )
 
 		}else if( utility::pathPointsToAFolder( volume ) ){
 
-			QStringList l ;
-
-			l << volume << "Nil" << "encfs" << "Nil" << "Nil" << "Nil" ;
-
-			this->mount( volumeEntryProperties( l ) ) ;
+			this->mount( volumeEntryProperties( { volume,"Nil","encfs","Nil","Nil","Nil" } ) ) ;
 		}
 	}
 }
@@ -884,13 +891,13 @@ void MainWindow::removeEntryFromTable( QString volume )
 	}
 }
 
-void MainWindow::volumeMiniProperties( volumeEntryProperties * volumeInfo )
+void MainWindow::volumeMiniProperties( bool valid,volumeEntryProperties * e )
 {
-	Object_raii( volumeInfo ) ;
+	std::unique_ptr< volumeEntryProperties > volumeInfo( e ) ;
 
 	this->disableAll() ;
 
-	if( volumeInfo ){
+	if( valid ){
 
 		this->updateList( *volumeInfo ) ;
 		this->enableAll() ;
@@ -899,19 +906,14 @@ void MainWindow::volumeMiniProperties( volumeEntryProperties * volumeInfo )
 	}
 }
 
+void MainWindow::volumeMiniProperties( volumeEntryProperties * volumeInfo )
+{
+	this->volumeMiniProperties( volumeInfo,volumeInfo ) ;
+}
+
 void MainWindow::volumeMiniProperties_0( volumeEntryProperties * volumeInfo )
 {
-	Object_raii( volumeInfo ) ;
-
-	this->disableAll() ;
-
-	if( volumeInfo && volumeInfo->mounted() ){
-
-		this->updateList( *volumeInfo ) ;
-		this->enableAll() ;
-	}else{
-		this->pbUpdate() ;
-	}
+	this->volumeMiniProperties( volumeInfo && volumeInfo->mounted(),volumeInfo ) ;
 }
 
 void MainWindow::updateList( const volumeEntryProperties& entry )
@@ -1132,7 +1134,7 @@ void MainWindow::slotCurrentItemChanged( QTableWidgetItem * current,QTableWidget
 
 void MainWindow::disableAll()
 {
-	m_ui->pbclose->setEnabled( false ) ;
+	m_ui->pbmenu->setEnabled( false ) ;
 	m_ui->pbmount->setEnabled( false ) ;
 	m_ui->pbupdate->setEnabled( false ) ;
 	m_ui->tableWidget->setEnabled( false ) ;
@@ -1144,12 +1146,21 @@ void MainWindow::enableAll()
 	if( m_removeAllVolumes ){
 		return ;
 	}
-	m_ui->pbclose->setEnabled( true ) ;
+	m_ui->pbmenu->setEnabled( true ) ;
 	m_ui->pbupdate->setEnabled( true ) ;
 	m_ui->tableWidget->setEnabled( true ) ;
 	m_ui->pbmount->setEnabled( true ) ;
 	m_ui->tableWidget->setFocus() ;
 	m_ui->pbunlockencfs->setEnabled( true ) ;
+
+	if( utility::runningInMixedMode() ){
+
+		/*
+		 * FUSE related permission issues prevents us from currently supporting
+		 * unlocking encfs volumes when running in mixed mode.
+		 */
+		m_ui->pbunlockencfs->setEnabled( false ) ;
+	}
 }
 
 void MainWindow::enableAll_1()
@@ -1180,4 +1191,22 @@ MainWindow::~MainWindow()
 			f.remove() ;
 		}
 	}
+
+	QVector<int> e ;
+
+	auto q = m_ui->tableWidget ;
+
+	const QRect& r = this->window()->geometry() ;
+
+	e << r.x()
+	  << r.y()
+	  << r.width()
+	  << r.height()
+	  << q->columnWidth( 0 )
+	  << q->columnWidth( 1 )
+	  << q->columnWidth( 2 )
+	  << q->columnWidth( 4 )
+	  << q->columnWidth( 5 ) ;
+
+	utility::setWindowDimensions( e,"zuluMount" ) ;
 }
