@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (c) 2012
+ *  Copyright (c) 2012-2015
  *  name : Francis Banyikwa
  *  email: mhogomchungu@gmail.com
  *  This program is free software: you can redistribute it and/or modify
@@ -52,12 +52,14 @@ public slots:
 	void raiseWindow( void ) ;
 	void raiseWindow( QString ) ;
 private slots:
+	void closeApplication( void ) ;
 	void unlockencfs( void ) ;
 	void showVisibleVolumeList( void ) ;
 	void showHiddenVolumeList( void ) ;
 	void removeVolumeFromHiddenVolumeList( QAction * ) ;
 	void removeVolumeFromVisibleVolumeList( QAction * ) ;
 	void startGUI( void ) ;
+	void volumeMiniProperties( bool,volumeEntryProperties * ) ;
 	void volumeMiniProperties( volumeEntryProperties * ) ;
 	void volumeMiniProperties_0( volumeEntryProperties * ) ;
 	void showMoungDialog( const volumeEntryProperties& ) ;
@@ -72,7 +74,7 @@ private slots:
 	void slotMount( void ) ;
 	void unMountAll( void ) ;
 	void pbUmount( void ) ;
-	void pbClose( void ) ;
+	void pbMenu( void ) ;
 	void slotTrayClicked( QSystemTrayIcon::ActivationReason ) ;
 	void slotCurrentItemChanged( QTableWidgetItem *,QTableWidgetItem * ) ;
 	void enableAll( void ) ;
@@ -91,7 +93,9 @@ private slots:
 	void favoriteClicked( QAction * ) ;
 	void openMountPointPath( QString ) ;
 	void licenseInfo( void ) ;
+	void updateCheck( void ) ;
 private:
+	void autoUpdateCheck( void ) ;
 	void updateVolumeList( const QVector< volumeEntryProperties >& ) ;
 	void openMountPoint( const QString& ) ;
 	QFont getSystemVolumeFont( void ) ;
