@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (c) 2012
+ *  Copyright (c) 2012-2015
  *  name : Francis Banyikwa
  *  email: mhogomchungu@gmail.com
  *  This program is free software: you can redistribute it and/or modify
@@ -23,9 +23,6 @@
 #include <QStringList>
 #include <QDebug>
 
-#include <poll.h>
-#include <fcntl.h>
-
 #include "../zuluCrypt-gui/utility.h"
 #include "../zuluCrypt-gui/task.h"
 #include "zulumounttask.h"
@@ -78,24 +75,15 @@ void monitor_mountinfo::run()
 	connect( this,SIGNAL( volumeRemoved( QString ) ),
 		 m_babu,SLOT( volumeRemoved( QString ) ) ) ;
 
-	utility::fileHandle f ;
+	utility::monitor_mountinfo monitor ;
+
+	if( monitor ){
 
-	if( !f.open( "/proc/self/mountinfo" ) ){
-		return this->failedToStart() ;
-	}else{
 		m_running = true ;
+	}else{
+		return this->failedToStart() ;
 	}
 
-	struct pollfd monitor ;
-
-	monitor.fd     = f.handle() ;
-	monitor.events = POLLPRI ;
-
-	auto _loop = [&](){
-		poll( &monitor,1,-1 ) ;
-		return 1 ;
-	} ;
-
 	auto _unmountProperty = [&]( const QString& volume ){
 
 		Task::exec( [ &,volume ](){
@@ -137,7 +125,7 @@ void monitor_mountinfo::run()
 		return !oldMountList.contains( e ) ;
 	} ;
 
-	while( _loop() ){
+	while( monitor.gotEvent() ){
 
 		newMountList = zuluMountTask::mountedVolumeList() ;
 
