@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (c) 2012
+ *  Copyright (c) 2012-2015
  *  name : Francis Banyikwa
  *  email: mhogomchungu@gmail.com
  *  This program is free software: you can redistribute it and/or modify
@@ -40,7 +40,6 @@
 #include "bin_path.h"
 #include "../zuluCrypt-gui/task.h"
 #include "../zuluCrypt-gui/dialogmsg.h"
-#include "../zuluCrypt-gui/userfont.h"
 #include "../zuluCrypt-gui/tablewidget.h"
 #include "../zuluCrypt-gui/utility.h"
 #include "mountoptions.h"
@@ -68,8 +67,7 @@ mountPartition::mountPartition( QWidget * parent,QTableWidget * table ) : QWidge
 
 	m_ui->pbMountFolder->setIcon( QIcon( ":/folder.png" ) ) ;
 
-	userfont F( this ) ;
-	this->setFont( F.getFont() ) ;
+	this->setFont( parent->font() ) ;
 
 	m_ui->pbMountFolder->setVisible( false ) ;
 
@@ -232,7 +230,11 @@ void mountPartition::showFileSystemOptionWindow()
 
 void mountPartition::doAction( QAction * ac )
 {
-	if( ac->text() == tr( "Set File System Options" ) ){
+	auto e = ac->text() ;
+
+	e.remove( "&" ) ;
+
+	if( e == tr( "Set File System Options" ) ){
 		this->showFileSystemOptionWindow() ;
 	}else{
 		this->showOffSetWindowOption() ;
