@@ -1,6 +1,6 @@
 /*
  *
- *  Copyright (c) 2014
+ *  Copyright (c) 2014-2015
  *  name : Francis Banyikwa
  *  email: mhogomchungu@gmail.com
  *  This program is free software: you can redistribute it and/or modify
@@ -25,6 +25,78 @@
 #include <QDebug>
 #include <QFile>
 
+static QString _convert_lvm_path( const QString& dev )
+{
+	QString volume = dev ;
+	QByteArray e = dev.toLatin1() ;
+
+	char * begin = e.data() ;
+	char * end = begin + e.size() ;
+
+	char * k ;
+	char * c ;
+	char * d ;
+
+	for( auto it = begin + 3 ; it < end ; it++ ){
+
+		k = it - 2 ;
+		c = it - 1 ;
+		d = it ;
+
+		if( *k != '-' && *c == '-' && *d != '-' ){
+
+			*c = '/' ;
+
+			volume = e ;
+
+			while( volume.contains( "--" ) ){
+
+				volume.replace( "--","-" ) ;
+			}
+
+			break ;
+		}
+	}
+
+	return volume ;
+}
+
+static QString _convert_md_raid_path( const QString& dev,bool wait )
+{
+	QString volume = dev ;
+
+	QString dev_1 ;
+	QDir d( "/dev/md/" ) ;
+	QDir f ;
+
+	if( wait ){
+		/*
+		 * wait for a while because things dont always happen as expected if we check too soon.
+		 */
+		utility::Task::wait( 4 ) ;
+	}
+
+	if( d.exists() ){
+
+		QStringList l = d.entryList() ;
+
+		for( const auto& it : l ){
+
+			dev_1 = "/dev/md/" + it ;
+			f.setPath( dev_1 ) ;
+
+			if( f.canonicalPath() == dev ){
+
+				volume = dev_1 ;
+
+				break ;
+			}
+		}
+	}
+
+	return volume ;
+}
+
 static QString _device( const QString& device )
 {
 	if( device.startsWith( "UUID" ) ){
@@ -140,7 +212,85 @@ Task::future< utility::Task >& zuluMountTask::unmountVolume( const QString& volu
 
 static QString _excludeVolumePath()
 {
-	return QDir::homePath() + "/.zuluCrypt/zuluMount-gui-excludeVolumes" ;
+	return utility::homePath() + "/.zuluCrypt/zuluMount-gui-excludeVolumes" ;
+}
+
+struct deviceList
+{
+	deviceList( const QString& dev,const QString& n ) : uniqueName( n )
+	{
+		if( dev.startsWith( "/dev/dm-" ) ){
+
+			QFile file( "/sys/block/" + dev.split( '/' ).last() + "/dm/name" ) ;
+
+			if( file.open( QIODevice::ReadOnly ) ){
+
+				QString e = file.readAll() ;
+				e.truncate( e.size() - 1 ) ;
+				device = _convert_lvm_path( "/dev/" + e ) ;
+			}else{
+				device = dev ;
+			}
+
+		}else if( dev.startsWith( "/dev/md" ) ){
+
+			device = _convert_md_raid_path( dev,false ) ;
+		}else{
+			device = dev ;
+		}
+	}
+	deviceList()
+	{
+	}
+	QString device ;
+	QString uniqueName ;
+};
+
+static QVector< deviceList > _getDevices()
+{
+	const char * p = "/dev/disk/by-id/" ;
+
+	QDir d( p ) ;
+	QDir e ;
+
+	QStringList l = d.entryList() ;
+
+	l.removeOne( "." ) ;
+	l.removeOne( ".." ) ;
+
+	QVector< deviceList > devices ;
+
+	if( l.isEmpty() ){
+
+		return devices ;
+	}else{
+		for( const auto& it : l ){
+
+			e.setPath ( p + it ) ;
+
+			devices.append( deviceList( e.canonicalPath(),it ) ) ;
+		}
+	}
+
+	return devices ;
+}
+
+static QString _getUniqueName( const QString& device )
+{
+	for( const auto& it : _getDevices() ){
+
+		if( it.device == device ){
+
+			return it.uniqueName ;
+		}
+	}
+
+	return QString() ;
+}
+
+static QStringList _split( QFile& f )
+{
+	return utility::split( f.readAll() ) ;
 }
 
 void zuluMountTask::addVolumeToHiddenVolumeList( const QString& e )
@@ -149,7 +299,12 @@ void zuluMountTask::addVolumeToHiddenVolumeList( const QString& e )
 
 	if( f.open( QIODevice::WriteOnly | QIODevice::Append ) ){
 
-		f.write( e.toLatin1() + "\n" ) ;
+		QString a = _getUniqueName( e ) ;
+
+		if( !a.isEmpty() ){
+
+			f.write( a.toLatin1() + "\n" ) ;
+		}
 	}
 }
 
@@ -159,7 +314,21 @@ QStringList zuluMountTask::hiddenVolumeList()
 
 	if( f.open( QIODevice::ReadOnly ) ){
 
-		return QString( f.readAll() ).split( '\n',QString::SkipEmptyParts ) ;
+		QVector< deviceList > l = _getDevices() ;
+
+		QStringList e ;
+
+		QStringList g = _split( f ) ;
+
+		for( const auto& it : l ){
+
+			if( g.contains( it.uniqueName ) ){
+
+				e.append( it.device ) ;
+			}
+		}
+
+		return  e ;
 	}else{
 		return QStringList() ;
 	}
@@ -171,9 +340,9 @@ void zuluMountTask::removeVolumeFromHiddenVolumeList( const QString& e )
 
 	if( f.open( QIODevice::ReadOnly ) ){
 
-		auto l = QString( f.readAll() ).split( '\n',QString::SkipEmptyParts ) ;
+		QStringList l = _split( f ) ;
 
-		l.removeAll( e ) ;
+		l.removeAll( _getUniqueName( e ) ) ;
 
 		f.close() ;
 
@@ -268,10 +437,15 @@ volumeMiniPropertiesTaskResult zuluMountTask::volumeMiniProperties( const QStrin
 			if( it.startsWith( "loop" ) ){
 
 				e = QString( "/sys/block/%1/loop/backing_file" ).arg( it ) ;
+
 				f.setFileName( e ) ;
-				f.open( QIODevice::ReadOnly ) ;
-				s = f.readAll() ;
-				f.close() ;
+
+				if( f.open( QIODevice::ReadOnly ) ){
+
+					s = f.readAll() ;
+
+					f.close() ;
+				}
 
 				if( s == dev ){
 
@@ -282,7 +456,7 @@ volumeMiniPropertiesTaskResult zuluMountTask::volumeMiniProperties( const QStrin
 		return true ;
 	} ;
 
-	volumeMiniPropertiesTaskResult s = { volume,false,nullptr } ;
+	volumeMiniPropertiesTaskResult s{ volume,false,nullptr } ;
 
 	if( !volume.startsWith( "UUID" ) && !volume.startsWith( "/dev/" ) ){
 
@@ -319,43 +493,9 @@ volumeMiniPropertiesTaskResult zuluMountTask::deviceProperties( const zuluMountT
 {
 	auto _mdRaidDevice = [&]( const QString& device ){
 
-		auto _mdRaidPath = []( const QString& dev ){
+		QString d = _convert_md_raid_path( device,true ) ;
 
-			QString volume = dev ;
-
-			QString dev_1 ;
-			QDir d( "/dev/md/" ) ;
-			QDir f ;
-
-			/*
-			* wait for a while because things dont always happen as expected if we check too soon.
-			*/
-			utility::Task::wait( 4 ) ;
-
-			if( d.exists() ){
-
-				QStringList l = d.entryList() ;
-
-				for( const auto& it : l ){
-
-					dev_1 = "/dev/md/" + it ;
-					f.setPath( dev_1 ) ;
-
-					if( f.canonicalPath() == dev ){
-
-						volume = dev_1 ;
-
-						break ;
-					}
-				}
-			}
-
-			return volume ;
-		} ;
-
-		QString d = _mdRaidPath( device ) ;
-
-		volumeMiniPropertiesTaskResult s = { d,false,nullptr } ;
+		volumeMiniPropertiesTaskResult s{ d,false,nullptr } ;
 
 		if( deviceProperty.added ){
 
@@ -369,45 +509,9 @@ volumeMiniPropertiesTaskResult zuluMountTask::deviceProperties( const zuluMountT
 
 	auto _dmDevice = [&]( const QString& device ){
 
-		auto _convertLVM = []( const QString& dev ){
+		QString d = _convert_lvm_path( device ) ;
 
-			QString volume = dev ;
-			QByteArray e = dev.toLatin1() ;
-
-			char * begin = e.data() ;
-			char * end = begin + e.size() ;
-
-			char * k ;
-			char * c ;
-			char * d ;
-
-			for( auto it = begin + 3 ; it < end ; it++ ){
-
-				k = it - 2 ;
-				c = it - 1 ;
-				d = it ;
-
-				if( *k != '-' && *c == '-' && *d != '-' ){
-
-					*c = '/' ;
-
-					volume = e ;
-
-					while( volume.contains( "--" ) ){
-
-						volume.replace( "--","-" ) ;
-					}
-
-					break ;
-				}
-			}
-
-			return volume ;
-		} ;
-
-		QString d = _convertLVM( device ) ;
-
-		volumeMiniPropertiesTaskResult s = { d,false,nullptr } ;
+		volumeMiniPropertiesTaskResult s{ d,false,nullptr } ;
 
 		if( deviceProperty.added ){
 
@@ -428,7 +532,7 @@ volumeMiniPropertiesTaskResult zuluMountTask::deviceProperties( const zuluMountT
 				device.startsWith( "/dev/mmc" ) ;
 		} ;
 
-		volumeMiniPropertiesTaskResult s = { "",false,nullptr } ;
+		volumeMiniPropertiesTaskResult s{ QString(),false,nullptr } ;
 
 		if( _allowed_device( device ) ){
 
@@ -447,8 +551,7 @@ volumeMiniPropertiesTaskResult zuluMountTask::deviceProperties( const zuluMountT
 
 	auto _shouldNotGetHere = [](){
 
-		volumeMiniPropertiesTaskResult s = { "",false,nullptr } ;
-		return s ;
+		return volumeMiniPropertiesTaskResult{ QString(),false,nullptr } ;
 	} ;
 
 	QString device = QString( "/dev/%1" ).arg( deviceProperty.volumeName ) ;
